<?php
/**
 * Custom settings for Advanced Custom Fields.
 *
 * @package WordPress
 * @version 1.0
 */

/**
 * Setup ACF
 */
function cm_acf_setup() {
	// Hide for all users, we will activate admin access below.
	acf_update_setting( 'show_admin', false );

	if ( function_exists( 'acf_add_options_page' ) ) {

		acf_add_options_page(
			array(
				'capability' => 'update_core',
				'icon_url'   => 'dashicons-admin-settings',
				'page_title' => 'Theme Settings',
				'position'   => '2.5',
				'redirect'   => false,
			)
		);

		acf_add_options_page(
			array(
				'icon_url'   => 'dashicons-networking',
				'page_title' => 'Social Media',
			)
		);

		acf_add_options_page(
			array(
				'icon_url'   => 'dashicons-flag',
				'page_title' => 'Alerts',
			)
		);

		/* // phpcs:ignore
		Keeping this code for later.
		acf_add_options_sub_page(
			array(
				'page_title'  => 'Social Media',
				'parent_slug' => $parent['menu_slug'],
			)
		);
		*/
	}

	/**
	 * Hide the featured image meta box on pages.
	 */
	function hide_featured_image_meta_box() {
		remove_meta_box( 'postimagediv', 'page', 'side' );
	}
	add_action( 'admin_head', 'hide_featured_image_meta_box' );
}
add_action( 'acf/init', 'cm_acf_setup' );


/**
 * Show ACF in admin menu for admins.
 *
 * @param [type] $show [desc].
 */
function cm_acf_show_for_admins( $show ) {
	return current_user_can( 'update_core' );
}
add_filter( 'acf/settings/show_admin', 'cm_acf_show_for_admins' );


/**
 * Add a CPT field to ACF's options.
 */
function cm_acf_cpt_selector() {
	include_once 'class-acf-cpt.php';
}
add_action( 'acf/include_fields', 'cm_acf_cpt_selector' );


/**
 * Save ACF fields to json files with custom path.
 *
 * @param [type] $path [desc].
 */
function cm_acf_save_json_location( $path ) {
	$path = get_template_directory() . '/functions/assets/json/acf';
	return $path;
}
add_filter( 'acf/settings/save_json', 'cm_acf_save_json_location' );


/**
 * Load ACF fields json files from custom path.
 *
 * @param [type] $paths [desc].
 */
function cm_acf_load_json_location( $paths ) {
	// remove original path (optional).
	unset( $paths[0] );
	// append path.
	$paths[] = get_template_directory() . '/functions/assets/json/acf';
	return $paths;
}
add_filter( 'acf/settings/load_json', 'cm_acf_load_json_location' );


/**
 * Merge fields with tabs where relevant.
 */
add_action(
	'admin_footer',
	function() {
		$screen = get_current_screen();
		if ( 'post' === $screen->base ) {
			echo '<!-- ACF Merge Tabs --><script>
			var $boxes = jQuery( \'#postbox-container-2 .postbox .acf-field-tab\' ).parent( \'.inside\' );
			if ( $boxes.length > 1 ) {
				var $firstBox = $boxes.first();
				$boxes.not( $firstBox ).each(function() {
					jQuery( this ).children().appendTo( $firstBox );
					jQuery( this ).parent( \'.postbox\' ).remove();
				});
			}</script>';
		}
	}
);
