<?php
/**
 * Disable comments everywhere.
 *
 * @package WordPress
 * @version 1.0
 */

/**
 * Disable support for comments and trackbacks in post types.
 */
function cm_disable_comments_for_post_types() {
	$post_types = get_post_types();
	foreach ( $post_types as $post_type ) {
		if ( post_type_supports( $post_type, 'comments' ) ) {
			remove_post_type_support( $post_type, 'comments' );
			remove_post_type_support( $post_type, 'trackbacks' );
		}
	}
}
add_action( 'admin_init', 'cm_disable_comments_for_post_types' );

/**
 * Close comments on the front-end.
 */
function cm_disable_comments_status() {
	return false;
}
add_filter( 'comments_open', 'cm_disable_comments_status', 20, 2 );
add_filter( 'pings_open', 'cm_disable_comments_status', 20, 2 );

/**
 * Hide existing comments.
 *
 * @param [type] $comments [description].
 */
function cm_disable_comments_hide_existing_comments( $comments ) {
	$comments = array();
	return $comments;
}
add_filter( 'comments_array', 'cm_disable_comments_hide_existing_comments', 10, 2 );

/**
 * Remove comments page in menu.
 */
function cm_disable_comments_menu() {
	remove_menu_page( 'edit-comments.php' );
}
add_action( 'admin_menu', 'cm_disable_comments_menu' );

/**
 * Redirect any user trying to access comments page.
 */
function cm_disable_comments_on_dashboard() {
	global $pagenow;
	if ( 'edit-comments.php' === $pagenow ) {
		wp_safe_redirect( admin_url() );
		exit;
	}
	remove_meta_box( 'dashboard_recent_comments', 'dashboard', 'normal' );
}
add_action( 'admin_init', 'cm_disable_comments_on_dashboard' );

/**
 * Remove comments links from admin bar.
 */
function cm_disable_comments_in_admin_bar() {
	if ( is_admin_bar_showing() ) {
		remove_action( 'admin_bar_menu', 'wp_admin_bar_comments_menu', 60 );
	}
}
add_action( 'init', 'cm_disable_comments_in_admin_bar' );
