<?php
/**
 * Functions related to content.
 *
 * @package WordPress
 * @version 1.0
 */

/**
 * Function for the on-page h1.
 *
 * @param [type] $post_id [description].
 */
function the_h1( $post_id ) {
	$page_heading = get_post_meta( $post_id, '_seo_heading', true );
	if ( $page_heading ) {
		$the_h1 = $page_heading;
	} else {
		if ( 'Home' === get_the_title( $post_id ) ) {
			$the_h1 = get_bloginfo( 'name' );
		} else {
			$the_h1 = get_the_title( $post_id );
		}
	}
	return $the_h1;
}


/**
 * Allow iframes with the following attributes.
 *
 * @param  [type] $allowedposttags [description].
 */
function cm_allow_attributes( $allowedposttags ) {
	$allowedposttags['a']      = array(
		'class'     => true,
		'data-name' => true,
		'href'      => true,
		'id'        => true,
		'itemprop'  => true,
		'style'     => true,
		'target'    => true,
		'title'     => true,
	);
	$allowedposttags['div']    = array(
		'class'     => true,
		'data-name' => true,
		'id'        => true,
		'itemprop'  => true,
		'style'     => true,
	);
	$allowedposttags['embed']  = array(
		'class'  => true,
		'height' => true,
		'id'     => true,
		'src'    => true,
		'type'   => true,
		'width'  => true,
	);
	$allowedposttags['iframe'] = array(
		'align'        => true,
		'class'        => true,
		'frameborder'  => true,
		'height'       => true,
		'id'           => true,
		'marginwidth'  => true,
		'marginheight' => true,
		'name'         => true,
		'scrolling'    => true,
		'src'          => true,
		'style'        => true,
		'width'        => true,
	);
	return $allowedposttags;
}
add_filter( 'wp_kses_allowed_html', 'cm_allow_attributes' );


/**
 * Allow oEmbeds to work with post meta.
 */
global $wp_embed;
add_filter( 'cm_oembed', array( $wp_embed, 'autoembed' ), 8 );
add_filter( 'cm_oembed', 'do_shortcode', 8 );


/**
 * Shorthand function for checking if we are on the homepage.
 */
function is_homepage() {
	return ( is_front_page() || is_page( 'home' ) );
}


/**
 * Filter the excerpt "read more" string.
 *
 * @param string $more "Read more" excerpt string.
 * @return string (Maybe) modified "read more" excerpt string.
 */
function cm_excerpt_continue( $more ) {
	return ' ...';
}
add_filter( 'excerpt_more', 'cm_excerpt_continue' );


/**
 * Get a specified word-count excerpt for a page.
 *
 * @param  [type] $post_id [description].
 * @param  [type] $length  [description].
 */
function content_excerpt( $post_id, $length ) {
	$sc_find     = array(
		'/\[acf(.*?)\]/s',
		'/\[audio(.*?)\]/s',
		'/\[btn(.*?)\]/s',
		'/\[caption(.*?)\]/s',
		'/\[\/caption(.*?)\]/s',
		'/\[contact-form-7(.*?)\]/s',
		'/\[gallery(.*?)\]/s',
		'/\[location(.*?)\]/s',
		'/\[pdf(.*?)\]/s',
		'/\[playlist(.*?)\]/s',
		'/\[video(.*?)\]/s',
		'/\[wp_caption(.*?)\]/s',
		'/\[wpvideo(.*?)\]/s',
	);
	$sc_replace  = array(
		'',
		'',
		'',
		'',
		'',
		'',
		'',
		'',
		'',
		'',
		'',
		'',
		'',
	);
	$get_content = get_post( $post_id );
	$content     = $get_content->post_content;
	$content     = preg_replace( $sc_find, $sc_replace, $get_content->post_content );
	$content     = str_replace( ']]>', ']]&gt;', $content );
	$regex       = '#(<h([1-6])[^>]*>)\s?(.*)?\s?(<\/h\2>)#';
	$content     = preg_replace( $regex, '', $content );
	$excerpt     = wp_trim_words( $content, $length, '... ' );
	return wp_kses_post( $excerpt );
}


/**
 * Get a page's top-level ancestor.
 * Usage example:
 * 14 === $post->post_parent || 14 === get_ancestor()
 */
function get_ancestor() {
	global $post;
	if ( $post->post_parent ) {
		$ancestors   = get_post_ancestors( $post->ID );
		$page_top    = count( $ancestors ) - 1;
		$parent_page = $ancestors[ $page_top ];
	} else {
		$parent_page = $post->ID;
	}
	return $parent_page;
}


/**
 * Filter <p> tags from images and iframes
 *
 * @param [type] $content [description].
 */
function cm_clean_up_p( $content ) {
	// see what we did there? Pee.
	$content = preg_replace( '/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(<\/a>)?\s*<\/p>/iU', '\1\2\3', $content );
	return preg_replace( '/<p>\s*(<iframe .*>*.<\/iframe>)\s*<\/p>/iU', '\1', $content );
}
add_filter( 'the_content', 'cm_clean_up_p' );


/**
 * Remove Private/Protected from post titles.
 *
 * @param  [type] $title [description].
 */
function cm_title_trim( $title ) {
	$title       = esc_attr( $title );
	$findthese   = array(
		'#Protected:#',
		'#Private:#',
	);
	$replacewith = array(
		'', // What to replace "Protected:" with.
		'', // What to replace "Private:" with.
	);
	$title       = preg_replace( $findthese, $replacewith, $title );
	return $title;
}
add_filter( 'the_title', 'cm_title_trim' );


/**
 * Insert containers around all the videos.
 *
 * @param [type] $html [description].
 * @param [type] $url [description].
 * @param [type] $attr [description].
 * @param [type] $post_id [description].
 */
function cm_video_container( $html, $url, $attr, $post_id ) {
	$return = $html;
	if ( strpos( $url, 'vimeo.com' ) || strpos( $url, 'youtube.com' ) ) {
		$return = '<div class="video"><div class="video--inner">' . $html . '</div></div>';
	}
	return $return;
}

add_filter( 'embed_oembed_html', 'cm_video_container', 10, 4 );


/**
 * Don't show related videos in YouTube embeds.
 *
 * @param  [type] $data [description].
 * @param  [type] $url  [description].
 * @param  array  $args [description].
 */
function cm_youtube_hide_related_videos( $data, $url, $args = array() ) {
	$data = preg_replace( '/(youtube\.com.*)(\?feature=oembed)(.*)/', '$1?' . apply_filters( 'cm_extra_querystring_parameters', 'wmode=transparent&amp;' ) . 'rel=0$3', $data );
	return $data;
}
add_filter( 'oembed_result', 'cm_youtube_hide_related_videos', 10, 3 );


/**
 * Shortcode for buttons.
 * [btn url="url" text=""]
 *
 * @param  [type] $atts [description].
 */
function cm_button( $atts ) {
	$btn = shortcode_atts(
		array(
			'text' => '',
			'url'  => '',
		),
		$atts
	);
	return '<a href="' . $btn['url'] . '" class="btn">' . $btn['text'] . '</a>';
}
add_shortcode( 'btn', 'cm_button' );


/**
 * Shortcode for PDF files.
 * [pdf url="url" orientation=""] - portrait by default, otherwise landscape can be specified
 *
 * @param  [type] $atts [description].
 */
function cm_pdf_embed( $atts ) {
	$pdf = shortcode_atts(
		array(
			'orientation' => 'portrait',
			'url'         => '',
		),
		$atts
	);
	return '<div class="content--pdf ' . $pdf['orientation'] . '"><embed height="100%" src="' . $pdf['url'] . '#view=FitH,top" type="application/pdf" width="100%"></embed></div>';
}
add_shortcode( 'pdf', 'cm_pdf_embed' );
