<?php
/**
 * Enqueue all files for the theme.
 *
 * @package WordPress
 * @version 1.0
 */

/**
 * Enqueue frontend scripts
 */
function cm_enqueue_frontend_scripts() {
	// Version number is being stripped anyway, this is to avoid linting errors.
	$version = '1.0';
	// jQuery.
	wp_deregister_script( 'jquery' );
	wp_register_script( 'jquery', includes_url( '/js/jquery/jquery.js' ), false, $version, true );
	wp_enqueue_script( 'jquery' );
	// Typekit.
	$typekit = get_option( 'theme_typekit' );
	if ( $typekit ) {
		wp_enqueue_style( 'typekit', $typekit, array(), $version );
	}
	// Theme stylesheet.
	wp_enqueue_style( 'site-style', get_template_directory_uri() . '/assets/css/style.css', array(), $version );
	// Theme scripts.
	wp_register_script( 'site-scripts', get_template_directory_uri() . '/assets/js/package.min.js', array( 'jquery' ), $version, true );
	wp_localize_script(
		'site-scripts',
		'siteAlertCookie',
		array(
			'large' => get_option( 'options_alert_large_cookie' ),
			'small' => get_option( 'options_alert_small_cookie' ),
		)
	);
	wp_enqueue_script( 'site-scripts' );
}


/**
 * Hook into the 'wp_enqueue_scripts' action
 */
add_action( 'wp_enqueue_scripts', 'cm_enqueue_frontend_scripts' );


/**
 * Deregister styles as required.
 */
function cm_deregister_css() {
	$page_form = get_post_meta( get_the_ID(), '_page_form', true );
	if ( '1' !== $page_form ) {
		if ( class_exists( 'WPCF7_ContactForm' ) ) {
			wp_deregister_style( 'contact-form-7' );
		}
	}
	if ( function_exists( 'display_cff' ) ) {
		wp_deregister_style( 'cff' );
	}
	wp_dequeue_style( 'sb-font-awesome' );
	wp_dequeue_style( 'sb_instagram_styles' );
	wp_dequeue_style( 'wp-block-library' );
}


/**
 * Deregister scripts as required.
 */
function cm_deregister_js() {
	$page_form = get_post_meta( get_the_ID(), '_page_form', true );
	if ( '1' !== $page_form ) {
		if ( class_exists( 'WPCF7_ContactForm' ) ) {
			wp_deregister_script( 'contact-form-7' );
		}
	}
	wp_deregister_style( 'sb-font-awesome' );
}

add_action( 'wp_print_scripts', 'cm_deregister_js', 100 );
add_action( 'wp_print_styles', 'cm_deregister_css', 100 );
