<?php
/**
 * Location shortcodes.
 *
 * @package WordPress
 * @version 1.0
 */

/**
 * Address custom post type.
 *
 * @param [type] $atts [description].
 */
function location_shortcode( $atts ) {
	ob_start();
	$atts       = shortcode_atts(
		array(
			'id'         => '',
			'show_title' => '',
		),
		$atts
	);
	$id         = $atts['id'];
	$show_title = $atts['show_title'];
	$options    = array(
		'p'              => $id,
		'post_type'      => 'location',
		'posts_per_page' => '1',
		'show_title'     => true,
	);
	// Query.
	$query = new WP_Query( $options );
	if ( $query->have_posts() ) {
		while ( $query->have_posts() ) {
			global $post;
			$query->the_post();
			$city        = get_post_meta( get_the_ID(), '_location_address_city', true );
			$contacts    = get_post_meta( get_the_ID(), '_location_contact_other', true );
			$email       = get_post_meta( get_the_ID(), '_location_contact_primary_email', true );
			$fax         = get_post_meta( get_the_ID(), '_location_contact_fax', true );
			$hours       = get_post_meta( get_the_ID(), '_location_hours_regular', true );
			$hours_other = get_post_meta( get_the_ID(), '_location_hours_other', true );
			$line1       = get_post_meta( get_the_ID(), '_location_address_line1', true );
			$line2       = get_post_meta( get_the_ID(), '_location_address_line2', true );
			$line3       = get_post_meta( get_the_ID(), '_location_address_line3', true );
			$location_id = get_option( 'theme_location_id' );
			$name        = get_post_meta( get_the_ID(), '_location_contact_primary_name', true );
			$notes       = get_post_meta( get_the_ID(), '_location_notes', true );
			$phone       = get_post_meta( get_the_ID(), '_location_contact_primary_telephone', true );
			$place_id    = get_post_meta( get_the_ID(), '_location_place_id', true );
			$position    = get_post_meta( get_the_ID(), '_location_contact_primary_position', true );
			$postcode    = get_post_meta( get_the_ID(), '_location_address_postcode', true );
			$schema      = get_post_meta( get_the_ID(), '_location_schema_classification', true );
			$state       = get_post_meta( get_the_ID(), '_location_address_state', true );
			if ( $email ) {
				$email_link = antispambot( $email, 1 );
			}
			echo '<div itemscope itemtype="http://schema.org/' . esc_attr( $schema ) . '" class="' . esc_attr( join( ' ', get_post_class() ) ) . '">';
			echo '<address itemprop="address" itemscope itemtype="http://schema.org/PostalAddress">';
			if ( 'false' !== $atts['show_title'] ) {
				echo '<div itemprop="name">' . esc_html( get_the_title() ) . '</div>';
			}
			// Street Address.
			if ( $line1 || $line2 || $line3 ) {
				echo '<div itemprop="streetAddress">' . esc_html( $line1 );
				if ( $line1 && $line2 ) {
					echo '<span>' . esc_html( $line2 ) . '</span>';
				};
				if ( $line1 && $line2 && $line3 ) {
					echo '<span>' . esc_html( $line3 ) . '</span>';
				};
				echo '</div>';
			};
			if ( $city || $postcode || $state ) {
				echo '<div class="location--city">';
				// City.
				echo $city ? '<span itemprop="addressLocality">' . esc_html( $city ) . '</span>' : '';
				if ( ( $city && $state ) || ( $city && $postcode && ! $state ) ) {
					echo ', ';
				}
				// State.
				echo $state ? '<span itemprop="addressRegion">' . esc_html( $state ) . '</span>' : '';
				if ( ( $state && $postcode ) || ( $city && $postcode && ! $state ) ) {
					echo ' ';
				}
				// Postcode.
				echo $postcode ? '<span itemprop="postalCode">' . esc_html( $postcode ) . '</span>' : '';
				echo '</div>';
			}
			// Primary Contact.
			if ( $name || $position || $phone ) {
				echo '<div class="location--telephone">';
				echo $name ? '<span class="name">' . esc_html( $name ) . '</span>' : '';
				echo $position ? '<span class="position">' . esc_html( $position ) . '</span>' : '';
				if ( $phone ) {
					$phone = str_replace( array( '(', ')' ), '', $phone );
					echo '<a href="tel:' . esc_html( str_replace( ' ', '', $phone ) ) . '" itemprop="telephone" onclick="ga(\'send\',\'event\',\'phone call\',\'click\');" x-ms-format-detection="none">' . esc_html( $phone ) . '</a>';
				}
				echo '</div>';
			}
			// Email.
			echo $email ? '<div class="location--email" itemprop="email"><a href="mailto:' . esc_html( $email_link ) . '"><span>' . esc_html( $email ) . '</span></a></div>' : '';
			// Fax.
			echo $fax ? '<div class="location--fax" itemprop="faxNumber" x-ms-format-detection="none"><span>' . esc_html( $fax ) . '</span></div>' : '';
			// Other Contacts.
			if ( $contacts ) {
				echo '<ul class="location--contacts">';
				for ( $i = 0; $i < $contacts; $i++ ) {
					$contact_email    = get_post_meta( get_the_ID(), '_location_contact_other_' . $i . '_email', true );
					$contact_name     = get_post_meta( get_the_ID(), '_location_contact_other_' . $i . '_name', true );
					$contact_phone    = get_post_meta( get_the_ID(), '_location_contact_other_' . $i . '_telephone', true );
					$contact_position = get_post_meta( get_the_ID(), '_location_contact_other_' . $i . '_position', true );
					if ( $contact_email ) {
						$contact_email_link = antispambot( $contact_email, 1 );
					}
					echo '<li>';
					echo $contact_name ? '<span class="name">' . esc_html( $contact_name ) . '</span>' : '';
					echo $contact_position ? '<span class="position">' . esc_html( $contact_position ) . '</span>' : '';
					if ( $contact_phone ) {
						$contact_phone = str_replace( array( '(', ')' ), '', $contact_phone );
						echo '<div class="location--telephone">';
						echo '<a href="tel:' . esc_html( str_replace( ' ', '', $contact_phone ) ) . '" itemprop="telephone" onclick="ga(\'send\',\'event\',\'phone call\',\'click\');" x-ms-format-detection="none">' . esc_html( $contact_phone ) . '</a>';
						echo '</div>';
					}
					echo $contact_email ? '<div class="location--email" itemprop="email"><a href="mailto:' . esc_html( $contact_email_link ) . '"><span>' . esc_html( $contact_email ) . '</span></a></div>' : '';
					echo '</li>';
				}
				echo '</ul>';
			}

			if ( $place_id || $hours || $hours_other ) {
				echo '<div class="location--hours">';
				if ( $place_id ) {
					// https://webmasters.stackexchange.com/questions/103058/is-it-possible-to-show-the-hours-from-google-maps-on-a-website-so-that-the-webs.
					$place_url     = 'https://www.google.com/maps/search/?api=1&query=Google&query_place_id=' . $place_id;
					$get_place_url = curl_init( $place_url ); // phpcs:ignore
					curl_setopt( $get_place_url, CURLOPT_RETURNTRANSFER, 1 ); // phpcs:ignore
					$response = curl_exec( $get_place_url ); // phpcs:ignore

					if ( preg_match( '/Monday/', $response ) ) {
						echo '<table class="regular">';
						for ( $i = 0; $i < 7; $i++ ) {
							$day   = jddayofweek( $i, 1 );
							$start = stripos( $response, '[\"' . $day . '\",' ) + strlen( $day ) + 9;
							echo '<tr itemprop="openingHours">';
							echo '<td class="day"><span>' . esc_html( $day ) . '</span></td>';
							echo '<td class="time"><span>' . esc_html( substr( $response, $start, stripos( $response, '\"]', $start ) - $start ) ) . '</span></td>';
							echo '</tr>';
						}
						echo '</table>';
					}
				} else {
					// Hours.
					if ( $hours ) {
						echo '<table class="regular">';
						for ( $i = 0; $i < $hours; $i++ ) {
							$day   = get_post_meta( get_the_ID(), '_location_hours_regular_' . $i . '_day', true );
							$open  = get_post_meta( get_the_ID(), '_location_hours_regular_' . $i . '_open', true );
							$close = get_post_meta( get_the_ID(), '_location_hours_regular_' . $i . '_close', true );
							// Not open at all (if the client uses this option).
							$closed     = get_post_meta( get_the_ID(), '_location_hours_regular_' . $i . '_closed', true );
							$open_ampm  = $open ? date( 'a', strtotime( $open ) ) : '';
							$open_at    = $open ? date( 'g:i', strtotime( $open ) ) : '';
							$close_ampm = $close ? date( 'a', strtotime( $close ) ) : '';
							$close_at   = $close ? date( 'g:i', strtotime( $close ) ) : '';
							// Get the short versions of our open and close for schema.
							$open_schema  = $open ? date( 'G:i', strtotime( $open ) ) : '';
							$close_schema = $close ? date( 'G:i', strtotime( $close ) ) : '';
							if ( '7 Days' === $day || 'Every Day' === $day || 'Monday-Friday' === $day || 'Seven Days' === $day || 'Weekdays' === $day ) {
								$day_schema = 'Mo-Fr';
							} elseif ( 'Saturday-Sunday' === $day || 'Weekends' === $day ) {
								$day_schema = 'Sa-Su';
							} elseif ( 'Monday-Saturday' === $day ) {
								$day_schema = 'Mo-Sa';
							} else {
								$day_schema = substr( $day, 0, 2 );
							}
							$datetime = ' content="' . $day_schema . ' ' . $open_schema . '-' . $close_schema . '"';
							if ( $closed ) {
								$datetime = '';
							}
							echo '<tr itemprop="openingHours"' . wp_kses_post( $datetime ) . '>';
							echo '<td class="day"><span>' . esc_html( $day ) . '</span></td>';
							if ( $open_at && $close_at ) {
								if ( '00:00:00' === $open && '00:00:00' === $close ) {
									// Open 24 hours.
									echo '<td class="time"><span>24 hours</span></td>';
								} else {
									// Not open 24 hours.
									echo '<td class="time"><span>' . esc_html( trim( $open_at, ':00' ) . $open_ampm ) . '-' . esc_html( trim( $close_at, ':00' ) . $close_ampm ) . '</span></td>';
								}
							} elseif ( $closed ) {
								echo '<td class="time"><span>closed</span></td>';
							}
							echo '</tr>';
						}
						echo '</table>';
					}
				}
				// Hours - Other.
				if ( $hours_other ) {
					echo '<table class="special">';
					for ( $i = 0; $i < $hours_other; $i++ ) {
						$day   = get_post_meta( get_the_ID(), '_location_hours_other_' . $i . '_day', true );
						$open  = get_post_meta( get_the_ID(), '_location_hours_other_' . $i . '_open', true );
						$close = get_post_meta( get_the_ID(), '_location_hours_other_' . $i . '_close', true );
						// Not open at all (if the client uses this option).
						$closed     = get_post_meta( get_the_ID(), '_location_hours_other_' . $i . '_closed', true );
						$open_ampm  = $open ? date( 'a', strtotime( $open ) ) : '';
						$open_at    = $open ? date( 'g:i', strtotime( $open ) ) : '';
						$close_ampm = $close ? date( 'a', strtotime( $close ) ) : '';
						$close_at   = $close ? date( 'g:i', strtotime( $close ) ) : '';
						echo '<tr itemprop="openingHours">';
						echo '<td class="day"><span>' . esc_html( $day ) . '</span></td>';
						if ( $open_at && $close_at ) {
							if ( '00:00:00' === $open && '00:00:00' === $close ) {
								// Open 24 hours.
								echo '<td class="time"><span>24 hours</span></td>';
							} else {
								// Not open 24 hours.
								echo '<td class="time"><span>' . esc_html( trim( $open_at, ':00' ) . $open_ampm ) . '-' . esc_html( trim( $close_at, ':00' ) . $close_ampm ) . '</span></td>';
							}
						} elseif ( $closed ) {
							echo '<td class="time"><span>closed</span></td>';
						}
						echo '</tr>';
					}
					echo '</table>';
				}
				echo '</div>';
			}
			// Notes.
			echo $notes ? '<div class="location--notes">' . wp_kses_post( nl2br( $notes ) ) . '</div>' : '';
			echo '</address>';
			if ( $location_id && $location_id === $id ) {
				get_template_part( 'partials/site/social' );
			}
			echo '</div>';
			$location_map_embed = get_post_meta( $id, '_location_map_embed', true );
			if ( $location_map_embed && strpos( $location_map_embed, 'google' ) !== false ) {
				// Only output if the content contains 'google'.
				echo '<div class="map">';
				echo wp_kses(
					$location_map_embed,
					array(
						'iframe' => array(
							'height' => array(),
							'src'    => array(),
							'style'  => array(),
							'width'  => array(),
						),
					)
				);
				echo '</div>';
			}
		}
		wp_reset_postdata();
	};
	$output = ob_get_clean();
	return $output;
}
// Full address including tags: [address slug="x"] or [address id="x"].
add_shortcode( 'location', 'location_shortcode' );


/**
 * Show the shortcode in the admin columns.
 *
 * @param [type] $defaults [description].
 */
function location_columns_head( $defaults ) {
	$defaults['shortcode'] = 'Shortcode';
	return $defaults;
}


/**
 * [location_columns_content description]
 *
 * @param [type] $column_name [description].
 * @param [type] $post_id   [description].
 */
function location_columns_content( $column_name, $post_id ) {
	if ( 'shortcode' === $column_name ) {
		echo '[location id="' . get_the_ID() . '"]<br>';
		echo '[location id="' . get_the_ID() . '" show_title="false"]';
	}
}

add_filter( 'manage_edit-location_columns', 'location_columns_head' );
add_action( 'manage_location_posts_custom_column', 'location_columns_content', 10, 2 );
