<?php
/**
 * Functions for images, galleries and the Media Library. See uploads.php for more.
 *
 * @package WordPress
 * @version 1.0
 */

/**
 * Thumbnail Support and custom image sizes - add more as needed.
 */
add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size( 480, 480, true );

/**
 * Add our preset sizes.
 */
$media_hero_crop          = get_option( 'options_media_preset_hero_crop' );
$media_hero_height        = get_option( 'options_media_preset_hero_height' );
$media_hero_name          = get_option( 'options_media_preset_hero_name' );
$media_hero_width         = get_option( 'options_media_preset_hero_width' );
$media_hero_home_crop     = get_option( 'options_media_preset_hero_home_crop' );
$media_hero_home_height   = get_option( 'options_media_preset_hero_home_height' );
$media_hero_home_name     = get_option( 'options_media_preset_hero_home_name' );
$media_hero_home_width    = get_option( 'options_media_preset_hero_home_width' );
$media_logo_crop          = get_option( 'options_media_preset_logo_crop' );
$media_logo_height        = get_option( 'options_media_preset_logo_height' );
$media_logo_name          = get_option( 'options_media_preset_logo_name' );
$media_logo_width         = get_option( 'options_media_preset_logo_width' );
$media_person_crop        = get_option( 'options_media_preset_person_crop' );
$media_person_height      = get_option( 'options_media_preset_person_height' );
$media_person_name        = get_option( 'options_media_preset_person_name' );
$media_person_width       = get_option( 'options_media_preset_person_width' );
$media_rectangle_l_crop   = get_option( 'options_media_preset_rectangle_large_crop' );
$media_rectangle_l_height = get_option( 'options_media_preset_rectangle_large_height' );
$media_rectangle_l_name   = get_option( 'options_media_preset_rectangle_large_name' );
$media_rectangle_l_width  = get_option( 'options_media_preset_rectangle_large_width' );
$media_rectangle_m_crop   = get_option( 'options_media_preset_rectangle_medium_crop' );
$media_rectangle_m_height = get_option( 'options_media_preset_rectangle_medium_height' );
$media_rectangle_m_name   = get_option( 'options_media_preset_rectangle_medium_name' );
$media_rectangle_m_width  = get_option( 'options_media_preset_rectangle_medium_width' );
$media_rectangle_s_crop   = get_option( 'options_media_preset_rectangle_small_crop' );
$media_rectangle_s_height = get_option( 'options_media_preset_rectangle_small_height' );
$media_rectangle_s_name   = get_option( 'options_media_preset_rectangle_small_name' );
$media_rectangle_s_width  = get_option( 'options_media_preset_rectangle_small_width' );
$media_square_l_crop      = get_option( 'options_media_preset_square_large_crop' );
$media_square_l_height    = get_option( 'options_media_preset_square_large_height' );
$media_square_l_name      = get_option( 'options_media_preset_square_large_name' );
$media_square_l_width     = get_option( 'options_media_preset_square_large_width' );
$media_square_m_crop      = get_option( 'options_media_preset_square_medium_crop' );
$media_square_m_height    = get_option( 'options_media_preset_square_medium_height' );
$media_square_m_name      = get_option( 'options_media_preset_square_medium_name' );
$media_square_m_width     = get_option( 'options_media_preset_square_medium_width' );
$media_square_s_crop      = get_option( 'options_media_preset_square_small_crop' );
$media_square_s_height    = get_option( 'options_media_preset_square_small_height' );
$media_square_s_name      = get_option( 'options_media_preset_square_small_name' );
$media_square_s_width     = get_option( 'options_media_preset_square_small_width' );
add_image_size( $media_hero_name, $media_hero_width, $media_hero_height, $media_hero_crop );
add_image_size( $media_hero_home_name, $media_hero_home_width, $media_hero_home_height, $media_hero_home_crop );
add_image_size( $media_logo_name, $media_logo_width, $media_logo_height, $media_logo_crop );
add_image_size( $media_person_name, $media_person_width, $media_person_height, $media_person_crop );
add_image_size( $media_rectangle_l_name, $media_rectangle_l_width, $media_rectangle_l_height, $media_rectangle_l_crop );
add_image_size( $media_rectangle_m_name, $media_rectangle_m_width, $media_rectangle_m_height, $media_rectangle_m_crop );
add_image_size( $media_rectangle_s_name, $media_rectangle_s_width, $media_rectangle_s_height, $media_rectangle_s_crop );
add_image_size( $media_square_l_name, $media_square_l_width, $media_square_l_height, $media_square_l_crop );
add_image_size( $media_square_m_name, $media_square_m_width, $media_square_m_height, $media_square_m_crop );
add_image_size( $media_square_s_name, $media_square_s_width, $media_square_s_height, $media_square_s_crop );

/**
 * Get media sizes from our options to replace WordPress defaults.
 */
$media_default_large_h     = get_option( 'options_media_default_large_height' );
$media_default_large_w     = get_option( 'options_media_default_large_width' );
$media_default_medium_h    = get_option( 'options_media_default_medium_height' );
$media_default_medium_w    = get_option( 'options_media_default_medium_width' );
$media_default_thumbnail_h = get_option( 'options_media_default_thumbnail_height' );
$media_default_thumbnail_w = get_option( 'options_media_default_thumbnail_width' );

/**
 * Update default media sizes.
 */
update_option( 'large_size_h', $media_default_large_h );
update_option( 'large_size_w', $media_default_large_w );
update_option( 'medium_size_h', $media_default_medium_h );
update_option( 'medium_size_w', $media_default_medium_w );
update_option( 'thumbnail_size_h', $media_default_thumbnail_h );
update_option( 'thumbnail_size_w', $media_default_thumbnail_w );

/**
 * Increase max srcset width to bigger than its default of 1600.
 */
add_filter(
	'max_srcset_image_width',
	function( $max_srcset_image_width, $size_array ) {
		return 2000;
	},
	10,
	2
);

/**
 * Remove WordPress gallery shortcode inline styles.
 */
add_filter( 'use_default_gallery_style', '__return_false' );

/**
 * Strip the gallery shortcode from the content.
 *
 * @param [type] $content [description].
 */
function cm_strip_shortcode_gallery( $content ) {
	preg_match_all( '/' . get_shortcode_regex() . '/s', $content, $matches, PREG_SET_ORDER );
	if ( ! empty( $matches ) ) {
		foreach ( $matches as $shortcode ) {
			if ( 'gallery' === $shortcode[2] ) {
				$pos = strpos( $content, $shortcode[0] );
				if ( false !== $pos ) {
					return substr_replace( $content, '', $pos, strlen( $shortcode[0] ) );
				}
			}
		}
	}
	return $content;
}

/**
 * Attach a class to linked images' parent anchors.
 *
 * @param  [type] $content [description].
 */
function cm_add_class_to_linked_images( $content ) {
	$classes = 'img';
	if ( preg_match( '/<a.*? class=".*?"><img/', $content ) ) {
		$content = preg_replace( '/(<a.*? class=".*?)(".*?><img)/', '$1 ' . $classes . '$2', $content );
	} else {
		$content = preg_replace( '/(<a.*?)><img/', '$1 class="' . $classes . '" ><img', $content );
	}
	return $content;
}
add_filter( 'the_content', 'cm_add_class_to_linked_images' );

/**
 * Always default to 'None' when inserting images.
 */
function cm_attachment_default_display_settings() {
	update_option( 'image_default_align', 'none' );
	update_option( 'image_default_link_type', 'none' );
	update_option( 'image_default_size', 'full' );
}
add_action( 'after_setup_theme', 'cm_attachment_default_display_settings' );

/**
 * Get the caption of an image and display it in our lightbox.
 *
 * @param [type] $link [description].
 * @param [type] $id   [description].
 */
function cm_add_caption_as_lightbox_title( $link, $id = null ) {
	$id         = intval( $id );
	$_post      = get_post( $id );
	$post_title = esc_attr( $_post->post_excerpt );
	return str_replace( '<a href', '<a title="' . $post_title . '" href', $link );
}
add_filter( 'wp_get_attachment_link', 'cm_add_caption_as_lightbox_title', 10, 2 );

// Switch default core markup to output HTML5 for galleries.
add_theme_support(
	'html5',
	array(
		'gallery',
		'caption',
	)
);

/**
 * Make galleries link to Media File.
 *
 * @param  [type] $out   [description].
 * @param  [type] $pairs [description].
 * @param  [type] $atts  [description].
 */
function gallery_should_link_to_files( $out, $pairs, $atts ) {
	$atts        = shortcode_atts(
		array(
			'link' => 'file',
		),
		$atts
	);
	$out['link'] = $atts['link'];
	return $out;
}
add_filter( 'shortcode_atts_gallery', 'gallery_should_link_to_files', 10, 3 );

/**
 * Add more file types to allowed uploads.
 *
 * @param  [type] $file_types [description].
 */
function cm_add_to_allowed_uploads( $file_types ) {
	$new_filetypes        = array();
	$new_filetypes['svg'] = 'image/svg+xml';
	$file_types           = array_merge( $file_types, $new_filetypes );
	return $file_types;
}
add_action( 'upload_mimes', 'cm_add_to_allowed_uploads' );

/**
 * Add loading="lazy" attribute to images output by the_post_thumbnail().
 *
 * @param string       $html The post thumbnail HTML.
 * @param int          $post_id The post ID.
 * @param string       $post_thumbnail_id The post thumbnail ID.
 * @param string|array $size The post thumbnail size. Image size or array of width and height values (in that order). Default 'post-thumbnail'.
 * @param string       $attr Query string of attributes.
 *
 * @return string The modified post thumbnail HTML.
 */
function cm_lazyload_post_thumbnail_html( $html, $post_id, $post_thumbnail_id, $size, $attr ) {
	return str_replace( '<img', '<img loading="lazy"', $html );
}
add_filter( 'post_thumbnail_html', 'cm_lazyload_post_thumbnail_html', 10, 5 );
