<?php
/**
 * Navigation functionality for themes.
 *
 * @package WordPress
 * @version 1.0
 */

// Register the menus and their positions.
register_nav_menus(
	array(
		'top'     => 'Top',
		'main'    => 'Main',
		'aside'   => 'Aside',
		'footer'  => 'Footer',
		'sitemap' => 'Sitemap',
	)
);

/**
 * Include page slug as nav classes on custom menus, and add a class if the page is a draft.
 *
 * @param [type] $classes description.
 * @param [type] $item description.
 */
function cm_menu_class_page_status( $classes, $item ) {
	$page       = get_post( $item );
	$page_id    = get_post( $item->object_id );
	$page_title = sanitize_title_with_dashes( $page->title );
	if ( 'taxonomy' === $page->type ) {
		$page_status = 'publish';
	} else {
		$page_status = get_post_status( $item->object_id );
	}
	$classes[] = 'menu-item-' . $page_title . ' menu-item-' . $page_status;
	return $classes;
}
add_filter( 'nav_menu_css_class', 'cm_menu_class_page_status', 10, 2 );

/**
 * Add search to nav.
 *
 * @param [type] $items description.
 * @param [type] $args description.
 */
function cm_nav_include_search( $items, $args ) {
	if ( 'main' === $args->theme_location ) {
		ob_start();
		get_search_form();
		$searchform = ob_get_contents();
		ob_end_clean();
		$items .= '<li class="menu-item-search">' . wp_kses_post( get_fa( 'fa-search' ) ) . '</li>';
	};
	return $items;
}
// Uncomment next line to add search icon to nav, according to your settings above.
// add_filter( 'wp_nav_menu_items', 'cm_nav_include_search', 10, 2 ); // phpcs:ignore.

/**
 * Exclude any pages using the thankyou page template.
 */
$exclude        = [];
$excluded_pages = '';
$args           = array(
	'meta_key'    => '_page_hide', // phpcs:ignore
	'meta_value'  => '1', // phpcs:ignore
	'post_status' => 'publish',
	'post_type'   => 'page',
);
$response_pages = get_posts( $args );
foreach ( $response_pages as $response_page ) {
	$exclude[]      = $response_page->ID;
	$excluded_pages = implode( ',', $exclude );
}

/**
 * Get submenu pages and add them to the menu dynamically.
 *
 * @param [type] $item_output description.
 * @param [type] $item description.
 * @param [type] $depth description.
 * @param [type] $args description.
 */
function cm_nav_dynamic_submenus( $item_output, $item, $depth, $args ) {
	global $excluded_pages;
	$args      = array(
		'child_of'    => $item->object_id,
		'depth'       => 0,
		'echo'        => 0,
		'exclude'     => $excluded_pages,
		'post_status' => 'publish',
		'title_li'    => '',
	);
	$has_pages = wp_list_pages( $args );
	if ( $has_pages ) {
		$item_output = $item_output . '<ul class="sub-menu" >' . wp_list_pages( $args ) . '</ul>';
	}
	return $item_output;
}
add_filter( 'walker_nav_menu_start_el', 'cm_nav_dynamic_submenus', 10, 4 );

// If you need to list taxonomy terms in your menus, use the Taxonomy Menu.
// Remember to add 'walker' => new Taxonomy_Menu(), to your wp_nav_menu.
/* require 'class-taxonomy-menu.php'; */ // phpcs:ignore
