<?php
/**
 * Add custom permalinks to the Permalinks settings page.
 * Custom post type permalinks need to be added manually at this stage.
 * TO DO: figure out nonce verification so the 'WPCS: CSRF ok.' override is no longer needed.
 *
 * @package WordPress
 * @version 1.0
 */

/**
 * Enable permalink customisation for CPT
 */
function cm_custom_permalinks() {

	// Our default custom post types and their taxonomies.
	// Attraction.
	if ( current_user_can( 'manage_options' ) && isset( $_POST['attraction_base'] ) ) { // WPCS: CSRF ok.
		update_option( 'attraction_base', sanitize_text_field( wp_unslash( $_POST['attraction_base'] ) ) ); // WPCS: CSRF ok.
	}
	/**
	 * Callback for the single attraction permalink.
	 */
	function attraction_base_callback() {
		$value = get_option( 'attraction_base' );
		echo '<input type="text" value="' . esc_attr( $value ) . '" name="attraction_base" id="attraction_base" class="regular-text code" />';
	}
	add_settings_field( 'attraction_base', 'Attraction base', 'attraction_base_callback', 'permalink', 'optional' );

	// Attraction Taxonomy.
	if ( current_user_can( 'manage_options' ) && isset( $_POST['attraction_category_base'] ) ) { // WPCS: CSRF ok.
		update_option( 'attraction-category_base', sanitize_text_field( wp_unslash( $_POST['attraction_category_base'] ) ) ); // WPCS: CSRF ok.
	}
	/**
	 * Callbacks for the permalinks - category
	 */
	function attraction_category_base_callback() {
		$value = get_option( 'attraction-category_base' );
		echo '<input type="text" value="' . esc_attr( $value ) . '" name="attraction_category_base" id="attraction_category_base" class="regular-text code" />';
	}
	add_settings_field( 'attraction_category_base', 'Attraction category base', 'attraction_category_base_callback', 'permalink', 'optional' );

	// Product.
	$cpt_product = get_option( 'options_cpt_default_product_register' );
	if ( $cpt_product ) {
		if ( current_user_can( 'manage_options' ) && isset( $_POST['product_base'] ) ) { // WPCS: CSRF ok.
			update_option( 'product_base', sanitize_text_field( wp_unslash( $_POST['product_base'] ) ) ); // WPCS: CSRF ok.
		}
		/**
		 * Callback for the single product permalink.
		 */
		function product_base_callback() {
			$value = get_option( 'product_base' );
			echo '<input type="text" value="' . esc_attr( $value ) . '" name="product_base" id="product_base" class="regular-text code" />';
		}
		add_settings_field( 'product_base', 'Product base', 'product_base_callback', 'permalink', 'optional' );

		// Product Taxonomy.
		if ( current_user_can( 'manage_options' ) && isset( $_POST['product_cat_base'] ) ) { // WPCS: CSRF ok.
			update_option( 'product_cat_base', sanitize_text_field( wp_unslash( $_POST['product_cat_base'] ) ) ); // WPCS: CSRF ok.
		}
		/**
		 * Callbacks for the permalinks - category
		 */
		function product_cat_base_callback() {
			$value = get_option( 'product_cat_base' );
			echo '<input type="text" value="' . esc_attr( $value ) . '" name="product_cat_base" id="product_cat_base" class="regular-text code" />';
		}
		add_settings_field( 'product_cat_base', 'Product category base', 'product_cat_base_callback', 'permalink', 'optional' );
	}
	// Project.
	$cpt_project = get_option( 'options_cpt_default_project_register' );
	if ( $cpt_project ) {
		if ( current_user_can( 'manage_options' ) && isset( $_POST['project_base'] ) ) { // WPCS: CSRF ok.
			update_option( 'project_base', sanitize_text_field( wp_unslash( $_POST['project_base'] ) ) ); // WPCS: CSRF ok.
		}
		/**
		 * Callback for the single project permalink.
		 */
		function project_base_callback() {
			$value = get_option( 'project_base' );
			echo '<input type="text" value="' . esc_attr( $value ) . '" name="project_base" id="project_base" class="regular-text code" />';
		}
		add_settings_field( 'project_base', 'Project base', 'project_base_callback', 'permalink', 'optional' );

		// Project Taxonomy.
		if ( current_user_can( 'manage_options' ) && isset( $_POST['project_cat_base'] ) ) { // WPCS: CSRF ok.
			update_option( 'project_cat_base', sanitize_text_field( wp_unslash( $_POST['project_cat_base'] ) ) ); // WPCS: CSRF ok.
		}
		/**
		 * Callbacks for the permalinks - category
		 */
		function project_cat_base_callback() {
			$value = get_option( 'project_cat_base' );
			echo '<input type="text" value="' . esc_attr( $value ) . '" name="project_cat_base" id="project_cat_base" class="regular-text code" />';
		}
		add_settings_field( 'project_cat_base', 'Project category base', 'project_cat_base_callback', 'permalink', 'optional' );
	}
	// Review.
	$cpt_review = get_option( 'options_cpt_default_review_register' );
	if ( $cpt_review ) {
		if ( current_user_can( 'manage_options' ) && isset( $_POST['review_base'] ) ) { // WPCS: CSRF ok.
			update_option( 'review_base', sanitize_text_field( wp_unslash( $_POST['review_base'] ) ) ); // WPCS: CSRF ok.
		}
		/**
		 * Callback for the single review permalink.
		 */
		function review_base_callback() {
			$value = get_option( 'review_base' );
			echo '<input type="text" value="' . esc_attr( $value ) . '" name="review_base" id="review_base" class="regular-text code" />';
		}
		add_settings_field( 'review_base', 'Review base', 'review_base_callback', 'permalink', 'optional' );

		// Review Taxonomy.
		if ( current_user_can( 'manage_options' ) && isset( $_POST['review_cat_base'] ) ) { // WPCS: CSRF ok.
			update_option( 'review_cat_base', sanitize_text_field( wp_unslash( $_POST['review_cat_base'] ) ) ); // WPCS: CSRF ok.
		}
		/**
		 * Callbacks for the permalinks - category
		 */
		function review_cat_base_callback() {
			$value = get_option( 'review_cat_base' );
			echo '<input type="text" value="' . esc_attr( $value ) . '" name="review_cat_base" id="review_cat_base" class="regular-text code" />';
		}
		add_settings_field( 'review_cat_base', 'Review category base', 'review_cat_base_callback', 'permalink', 'optional' );
	}
}
add_action( 'load-options-permalink.php', 'cm_custom_permalinks' );

/**
 * Do not allow slugs to match existing directories.
 * E.g. a media folder on the root will prevent a page slug of 'media' on the root.
 *
 * @param [type] $bool [description].
 * @param [type] $slug [description].
 */
function prevent_directory_slugs( $bool, $slug ) {
	if ( is_dir( ABSPATH . '/' . $slug ) ) {
		return true;
	}
	return $bool;
};
add_filter( 'wp_unique_post_slug_is_bad_hierarchical_slug', 'prevent_directory_slugs', 10, 2 );
