<?php
/**
 * Register any relevant extras for theme.
 * Choose from:
 * cm_register_cpt_brand
 * cm_register_cpt_event
 * cm_register_cpt_attraction
 * cm_register_cpt_product
 * cm_register_cpt_project
 * cm_register_cpt_review
 *
 * @package WordPress
 * @version 1.0
 */

add_action( 'init', 'cm_register_cpt_attraction' );
add_action( 'init', 'cm_register_cpt_event' );
add_action( 'init', 'cm_register_cpt_location' );

/**
 * Register Event CPT.
 */
function cm_register_cpt_event() {

	register_post_type(
		'event',
		array(
			'can_export'          => true,
			'capability_type'     => 'post',
			'description'         => '',
			'exclude_from_search' => false,
			'has_archive'         => false,
			'hierarchical'        => false,
			'label'               => 'Event',
			'labels'              => array(
				'add_new'               => 'Add Event',
				'add_new_item'          => 'Add New Event',
				'all_items'             => 'All Events',
				'archives'              => 'Events Archives',
				'edit_item'             => 'Edit Event',
				'featured_image'        => 'Event Photo',
				'filter_items_list'     => 'Filter Events',
				'insert_into_item'      => 'Insert into content',
				'items_list'            => 'Events',
				'items_list_navigation' => 'Events navigation',
				'menu_name'             => 'Events',
				'name'                  => 'Events',
				'name_admin_bar'        => 'Event',
				'new_item'              => 'New Event',
				'not_found'             => 'Not found',
				'not_found_in_trash'    => 'Not found in Trash',
				'parent_item_colon'     => 'Parent Event:',
				'remove_featured_image' => 'Remove image',
				'search_items'          => 'Search Events',
				'set_featured_image'    => 'Set image',
				'singular_name'         => 'Event',
				'update_item'           => 'Update Event',
				'uploaded_to_this_item' => 'Uploaded to this Event',
				'use_featured_image'    => 'Use as image',
				'view_item'             => 'View Event',
			),
			'menu_icon'           => 'dashicons-calendar',
			'menu_position'       => 5,
			'public'              => false,
			'publicly_queryable'  => true,
			'query_var'           => true,
			'rewrite'             => array(
				'hierarchical' => false,
				'slug'         => 'event',
				'with_front'   => true,
			),
			'rewrite'             => array(
				'slug'       => get_option( 'event_base' ),
				'with_front' => false,
			),
			'show_in_admin_bar'   => true,
			'show_in_menu'        => true,
			'show_in_nav_menus'   => true,
			'show_ui'             => true,
			'supports'            => array(
				'author',
				'editor',
				'page-attributes',
				'title',
			),
			'taxonomies'          => array(),
		)
	);
}


/**
 * Register Location CPT.
 */
function cm_register_cpt_location() {

	register_post_type(
		'location',
		array(
			'can_export'          => true,
			'capability_type'     => 'post',
			'description'         => '',
			'exclude_from_search' => true,
			'has_archive'         => false,
			'hierarchical'        => false,
			'labels'              => array(
				'add_new'               => 'Add New Location',
				'add_new_item'          => 'Add New Location',
				'all_items'             => 'All Locations',
				'archives'              => 'Location Archives',
				'description'           => 'Show location on site',
				'edit_item'             => 'Edit Location',
				'filter_items_list'     => 'Filter locations',
				'insert_into_item'      => 'Insert into content',
				'items_list'            => 'Locations',
				'items_list_navigation' => 'Locations navigation',
				'label'                 => 'Location',
				'menu_name'             => 'Locations',
				'name'                  => 'Locations',
				'name_admin_bar'        => 'Location',
				'new_item'              => 'New Location',
				'not_found'             => 'Not found',
				'not_found_in_trash'    => 'Not found in Trash',
				'search_items'          => 'Search Locations',
				'set_featured_image'    => 'Set image',
				'singular_name'         => 'Location',
				'update_item'           => 'Update Location',
				'view_item'             => 'View Location',
			),
			'menu_icon'           => 'dashicons-location',
			'menu_position'       => 2,
			'public'              => false,
			'publicly_queryable'  => false,
			'rewrite'             => false,
			'show_ui'             => true,
			'show_in_menu'        => true,
			'supports'            => array(
				'page-attributes',
				'title',
			),
			'show_in_admin_bar'   => false,
			'show_in_nav_menus'   => false,
			'taxonomies'          => array(),
		)
	);
}


/**
 * Register Attraction CPT.
 */
function cm_register_cpt_attraction() {
	/**
	 * Register the Attraction Custom Post Type.
	 */
	register_post_type(
		'attraction',
		array(
			'can_export'          => true,
			'capability_type'     => 'post',
			'description'         => '',
			'exclude_from_search' => false,
			'has_archive'         => false,
			'hierarchical'        => false,
			'label'               => 'Attraction',
			'labels'              => array(
				'add_new'               => 'Add Attraction',
				'add_new_item'          => 'Add New Attraction',
				'all_items'             => 'All Attractions',
				'archives'              => 'Attractions Archives',
				'edit_item'             => 'Edit Attraction',
				'featured_image'        => 'Photo',
				'filter_items_list'     => 'Filter attractions',
				'insert_into_item'      => 'Insert into content',
				'items_list'            => 'Attractions',
				'items_list_navigation' => 'Attractions navigation',
				'menu_name'             => 'Attractions',
				'name'                  => 'Attractions',
				'name_admin_bar'        => 'Attraction',
				'new_item'              => 'New Attraction',
				'not_found'             => 'Not found',
				'not_found_in_trash'    => 'Not found in Trash',
				'parent_item_colon'     => 'Parent Attraction:',
				'remove_featured_image' => 'Remove photo',
				'search_items'          => 'Search Attractions',
				'set_featured_image'    => 'Set photo',
				'singular_name'         => 'Attraction',
				'update_item'           => 'Update Attraction',
				'uploaded_to_this_item' => 'Uploaded to this attraction',
				'use_featured_image'    => 'Use as photo',
				'view_item'             => 'View Attraction',
			),
			'menu_icon'           => 'dashicons-palmtree',
			'menu_position'       => 5,
			'public'              => true,
			'publicly_queryable'  => true,
			'query_var'           => true,
			'rewrite'             => array(
				'hierarchical' => false,
				'slug'         => 'attraction',
				'with_front'   => true,
			),
			'rewrite'             => array(
				'slug'       => get_option( 'attraction_base' ),
				'with_front' => false,
			),
			'show_in_admin_bar'   => true,
			'show_in_menu'        => true,
			'show_in_nav_menus'   => true,
			'show_ui'             => true,
			'supports'            => array(
				'author',
				'editor',
				'page-attributes',
				'title',
			),
			'taxonomies'          => array(),
		)
	);

	/**
	 * Register the taxonomy.
	 */
	register_taxonomy(
		'attraction-category',
		array( 'attraction' ),
		array(
			'has_archive'       => false,
			'hierarchical'      => true,
			'labels'            => array(
				'add_new_item'               => 'Add New Category',
				'add_or_remove_items'        => 'Add or remove categories',
				'all_items'                  => 'All Categories',
				'choose_from_most_used'      => 'Choose from the most used categories',
				'edit_item'                  => 'Edit Categories',
				'menu_name'                  => 'Categories',
				'name'                       => 'Categories',
				'new_item_name'              => 'New Category Name',
				'not_found'                  => 'No categories found.',
				'parent_item'                => 'Parent Category',
				'parent_item_colon'          => 'Parent Category:',
				'popular_items'              => 'Popular Categories',
				'search_items'               => 'Search Categories',
				'separate_items_with_commas' => 'Separate categories with commas',
				'singular_name'              => 'Category',
				'update_item'                => 'Update Category',
				'view_item'                  => 'View Category',
			),
			'public'            => true,
			'query_var'         => true,
			'rewrite'           => array(
				'slug'       => get_option( 'attraction-category_base' ),
				'with_front' => false,
			),
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'show_tagcloud'     => false,
			'show_ui'           => true,
		)
	);
	/**
	 * Show the editor on the taxonomy term pages.
	 */
	add_filter( 'attraction-category_edit_form_fields', 'cm_show_description_editor', 10, 1 );
}
