<?php
/**
 * Add custom code to wp_head and wp_footer.
 *
 * @package WordPress
 * @version 1.0
 */

/**
 * Add GA code from ACF to the header.
 */
function cm_add_google_analytics_ua_code() {
	$this_server = $_SERVER['HTTP_HOST']; // phpcs:ignore
	if ( strpos( $this_server, '.local' ) === false ) { // Don't fire script locally.
		if ( '' !== get_option( 'options_google_analytics' ) ) {
			echo wp_kses(
				get_option( 'options_google_analytics' ),
				array(
					'script' => array(
						'src' => array(),
					),
				)
			);
			echo "\n";
			echo '<script>/* Track outbound links in Analytics */var trackOutboundLink = function(url) { gtag(\'event\', \'click\', { \'event_category\': \'outbound\', \'event_label\': url, \'transport_type\': \'beacon\', \'event_callback\': function(){ 	document.location = url; } }); }</script>';
			echo "\n";
		}
	}
}
add_action( 'wp_head', 'cm_add_google_analytics_ua_code', 10 );

/**
 * Add Google Tag Manager from ACF to the header.
 */
function cm_add_google_tag_head_code() {
	if ( '' !== get_option( 'options_google_tag_head' ) ) {
		echo wp_kses(
			get_option( 'options_google_tag_head' ),
			array(
				'script' => array(
					'src' => array(),
				),
			)
		);
		echo "\n";
	}
}
add_action( 'wp_head', 'cm_add_google_tag_head_code', 10 );

/**
 * Add Google Tag Manager from ACF to the body.
 */
function cm_add_google_tag_body_code() {
	if ( '' !== get_option( 'options_google_tag_body' ) ) {
		add_filter( // Allow GTM inline styles to be included.
			'safe_style_css',
			function( $inline_style ) {
				$inline_style[] = 'display';
				$inline_style[] = 'visibility';
				return $inline_style;
			}
		);
		echo wp_kses(
			get_option( 'options_google_tag_body' ),
			array(
				'iframe'   => array(
					'height' => array(),
					'src'    => array(),
					'style'  => array(),
					'width'  => array(),
				),
				'noscript' => array(),
			)
		);
		echo "\n";
	}
}
add_action( 'insert_gtm_inside_body', 'cm_add_google_tag_body_code' );

/**
 * Add script code from ACF to the header.
 */
function cm_add_scripts_to_head() {
	if ( '' !== get_option( 'options_scripts_head' ) ) {
		$scripts = get_option( 'options_scripts_head' );
		for ( $i = 0; $i < $scripts; $i++ ) {
			$header_script = get_option( 'options_scripts_head_' . $i . '_script' );
			echo wp_kses(
				$header_script,
				array(
					'script' => array(
						'src' => array(),
					),
				)
			);
			echo "\n";
		}
	}
}
add_action( 'wp_head', 'cm_add_scripts_to_head', 10 );

/**
 * Add script code from ACF to the footer.
 */
function cm_add_scripts_to_footer() {
	if ( '' !== get_option( 'options_scripts_footer' ) ) {
		$scripts = get_option( 'options_scripts_footer' );
		for ( $i = 0; $i < $scripts; $i++ ) {
			$footer_script = get_option( 'options_scripts_footer_' . $i . '_script' );
			echo wp_kses(
				$footer_script,
				array(
					'script' => array(
						'src' => array(),
					),
				)
			);
			echo "\n";
		}
	}
}
add_action( 'wp_footer', 'cm_add_scripts_to_footer', 10 );
