<?php
/**
 * Load SEO functions and scripts.
 *
 * @package WordPress
 * @version 1.0
 */

/*
 * All the requirements.
 */
require_once 'other.php';

/**
 * Load our stuff in wp_head.
 */
function cm_seo_into_wp_head() {
	require_once dirname( __FILE__ ) . '/seo/wp-head.php';
}
add_action( 'wp_head', 'cm_seo_into_wp_head', 1 );
require_once 'seo/wp-title.php';

/**
 * Bring in our styles and jQuery on the pages where we need them.
 *
 * @param [type] $hook [description].
 */
function cm_seo_scripts_and_styles( $hook ) {
	wp_enqueue_style( 'admin-css', get_template_directory_uri() . '/functions/assets/css/admin.css' );
	// To let WordPress show you the page you're on, use wp_die( $hook ).
	if ( 'post.php' === $hook || 'post-new.php' === $hook || 'term.php' === $hook ) {
		wp_enqueue_style( 'seo-styles', get_template_directory_uri() . '/functions/assets/css/seo.css' );
		wp_enqueue_script( 'seo-scripts', get_template_directory_uri() . '/functions/assets/js/seo.js', array(), '1.0.0', true );
		wp_enqueue_script( 'tax-filter', get_template_directory_uri() . '/functions/assets/js/taxonomy-filter.js', array(), '1.0.0', true );
		wp_enqueue_script( 'font-awesome', get_template_directory_uri() . '/functions/assets/js/fontawesome-all.min.js', array(), null, true );
		wp_enqueue_script( 'font-awesome-shims', get_template_directory_uri() . '/functions/assets/js/fontawesome-shims.min.js', array(), null, true );
	} else {
		return;
	}
}
add_action( 'admin_enqueue_scripts', 'cm_seo_scripts_and_styles' );


/**
 * Show the title and description to higher-level users.
 */
if ( current_user_can( 'delete_others_pages' ) ) {
	/**
	 * [cm_seo_metadata_columns description]
	 *
	 * @param [type] $columns [description].
	 */
	function cm_seo_metadata_columns( $columns ) {
		$metadata_columns = array(
			'metatitle'       => __( 'Meta Title' ),
			'metadescription' => __( 'Meta Description' ),
		);
		$columns          = array_merge( $columns, $metadata_columns );
		return $columns;
	}
	add_filter( 'manage_pages_columns', 'cm_seo_metadata_columns' );

	/**
	 * [cm_seo_metadata_column_content description]
	 *
	 * @param [type] $column_name [description].
	 * @param [type] $post_id     [description].
	 */
	function cm_seo_metadata_column_content( $column_name, $post_id ) {
		if ( 'metatitle' === $column_name ) {
			$metadata_title = get_post_meta( get_the_ID(), '_metadata_title', true );
			if ( $metadata_title ) {
				echo esc_html( $metadata_title );
			}
		}
		if ( 'metadescription' === $column_name ) {
			$metadata_description = get_post_meta( get_the_ID(), '_metadata_description', true );
			if ( $metadata_description ) {
				echo esc_html( $metadata_description );
			}
		}
	}
	add_action( 'manage_pages_custom_column', 'cm_seo_metadata_column_content', 10, 2 );
}

/**
 * Remove query strings from scripts and styles.
 */
function cm_remove_query_strings() {
	if ( ! is_admin() ) {
			add_filter( 'script_loader_src', 'cm_remove_query_strings_split', 15 );
			add_filter( 'style_loader_src', 'cm_remove_query_strings_split', 15 );
	}
}

/**
 * Remove query strings from scripts and styles.
 *
 * @param [type] $src [description].
 */
function cm_remove_query_strings_split( $src ) {
	$output = preg_split( '/(&ver|\?ver)/', $src );
	return $output[0];
}
add_action( 'init', 'cm_remove_query_strings' );

/**
 * Generate the sitemap.
 *
 * @param [type] $template [desc].
 */
function cm_generate_sitemap( $template ) {
	global $wp;
	if ( 'sitemap.xml' === $wp->request ) {
		return get_stylesheet_directory() . '/functions/sitemap/generate.php';
	}
	return $template;
}
add_filter( 'template_include', 'cm_generate_sitemap' );
