<?php
/**
 * Set up the basics.
 *
 * @package WordPress.
 * @version 1.0
 */

/**
 * Make magic when the theme is activated.
 */
// FontAwesome weight: fad, fal, far, fas.
// Also need to update _dev/css/variables/_fonts.scss.
update_option( 'theme_fontawesome', 'far' );
// Location: update with ID of main location.
update_option( 'theme_location_id', 341 );
// Fonts - Google: separate multiple fonts with a pipe (|).
// update_option( 'theme_googlefont', '' );
// Fonts - Typekit: use URL of kit.
// update_option( 'theme_typekit', '' );
// Custom image sizes; add as required.
/* add_image_size( $name, $width, $height, $crop ); */ // phpcs:ignore


/**
 * [sitename] — Site name shortcode.
 */
add_shortcode(
	'sitename',
	function() {
		return get_bloginfo();
	}
);


/**
 * Template Stylesheet Directory
 */
function theme_url() {
	return get_stylesheet_directory_uri();
}


/**
 * Template Stylesheet Directory
 */
function theme_dir() {
	return get_stylesheet_directory();
}


/**
 * Template Images Directory
 */
function theme_img_dir() {
	return theme_url() . '/assets/img';
}


/**
 * Template Images Directory
 */
function theme_fonts_dir() {
	return theme_url() . '/assets/fonts/googlefonts';
}


/**
 * Remove Emojis
 */
remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
remove_action( 'wp_print_styles', 'print_emoji_styles' );
remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
remove_action( 'admin_print_styles', 'print_emoji_styles' );
add_filter( 'emoji_svg_url', '__return_false' );


/**
 * Favicon Location
 */
function cm_favicon() {
	$icon_path = theme_img_dir() . '/icons';
	echo '<link rel="apple-touch-icon" href="' . esc_url( $icon_path ) . '/favicon.png">'; // 192px.
	echo '<link rel="icon" type="image/png" href="' . esc_url( $icon_path ) . '/favicon.png" />'; // 192px.
	echo '<link rel="icon shortcut" href="/favicon.ico" type="image/x-icon" />'; // 32px.
}
add_action( 'wp_head', 'cm_favicon' );


/**
 * Echo Font Awesome via a function to better control weights.
 *
 * @param [type] $icon [description].
 */
function fa( $icon ) {
	$fa = get_option( 'theme_fontawesome' );
	echo wp_kses_post( '<i class="' . $fa . ' ' . $icon . ' icon"></i>' );
}


/**
 * Echo Font Awesome via a function to better control weights.
 *
 * @param [type] $icon [description].
 */
function fab( $icon ) {
	echo wp_kses_post( '<i class="fab ' . $icon . ' icon"></i>' );
}


/**
 * Return Font Awesome via a function to better control weights.
 *
 * @param [type] $icon [description].
 */
function get_fa( $icon ) {
	$fa = get_option( 'theme_fontawesome' );
	return wp_kses_post( '<i class="' . $fa . ' ' . $icon . ' icon"></i>' );
}


/**
 * Return Font Awesome via a function to better control weights.
 *
 * @param [type] $icon [description].
 */
function get_fab( $icon ) {
	return wp_kses_post( '<i class="fab ' . $icon . ' icon"></i>' );
}


/**
 * Don't load styles for these things.
 */
function cm_deregister_styles() {
	wp_deregister_style( 'contact-form-7' );
}
add_action( 'wp_print_styles', 'cm_deregister_styles', 100 );


/**
 * Added for backwards compatibility to support WordPress versions prior to 5.2.0.
 */
if ( ! function_exists( 'wp_body_open' ) ) {
	/**
	 * Fire the wp_body_open action.
	 */
	function wp_body_open() {
			/**
			 * Triggered after the opening <body> tag.
			 */
			do_action( 'wp_body_open' );
	}
}


/**
 * Functions to fire when theme is activated.
 */
if ( isset( $_GET['activated'] ) && is_admin() ) { // phpcs:ignore

	// Blog Category.
	wp_update_term(
		1,
		'category',
		array(
			'name' => 'News',
		)
	);

	// Description.
	update_option( 'blogdescription', '' );

	// Pages.
	// Create 'Home'.
	if ( get_page_by_title( 'Home' ) === null ) {
		$page_title  = 'Home';
		$page_get    = get_page_by_title( $page_title );
		$page_create = array(
			'menu_order'  => '1',
			'post_status' => 'publish',
			'post_title'  => $page_title,
			'post_type'   => 'page',
		);
		if ( ! isset( $page_get->ID ) ) {
			$page_id = wp_insert_post( $page_create );
			if ( ! empty( $page_template ) ) {
				update_post_meta( $page_id, '_wp_page_template', $page_template );
			}
			update_option( 'page_on_front', $page_id );
			update_option( 'show_on_front', 'page' );
		}
	}
	// Create 'About'.
	if ( get_page_by_title( 'About' ) === null ) {
		$page_title  = 'About';
		$page_get    = get_page_by_title( $page_title );
		$page_create = array(
			'menu_order'  => '5',
			'post_status' => 'publish',
			'post_title'  => $page_title,
			'post_type'   => 'page',
		);
		if ( ! isset( $page_get->ID ) ) {
			$page_id = wp_insert_post( $page_create );
			if ( ! empty( $page_template ) ) {
				update_post_meta( $page_id, '_wp_page_template', $page_template );
			}
		}
	}
	// Create 'Contact'.
	if ( get_page_by_title( 'Contact' ) === null ) {
		$page_title  = 'Contact';
		$page_get    = get_page_by_title( $page_title );
		$page_create = array(
			'menu_order'  => '6',
			'post_status' => 'publish',
			'post_title'  => $page_title,
			'post_type'   => 'page',
		);
		if ( ! isset( $page_get->ID ) ) {
			$page_id = wp_insert_post( $page_create );
			if ( ! empty( $page_template ) ) {
				update_post_meta( $page_id, '_wp_page_template', $page_template );
			}
		}
	}
	// Create 'Privacy'.
	if ( get_page_by_title( 'Privacy' ) === null ) {
		$page_title  = 'Privacy';
		$page_get    = get_page_by_title( $page_title );
		$page_create = array(
			'menu_order'  => '1000',
			'post_status' => 'publish',
			'post_title'  => $page_title,
			'post_type'   => 'page',
		);
		if ( ! isset( $page_get->ID ) ) {
			$page_id = wp_insert_post( $page_create );
			if ( ! empty( $page_template ) ) {
				update_post_meta( $page_id, '_wp_page_template', $page_template );
				update_post_meta( $page_id, '_metadata_sitemap', '1' );
			}
			update_option( 'wp_page_for_privacy_policy', $page_id );
		}
	}
	// Delete 'Privacy Policy'.
	if ( get_page_by_title( 'Privacy Policy' ) ) {
		$page_title = 'Privacy Policy';
		$page_get   = get_page_by_title( $page_title );
		if ( isset( $page_get->ID ) ) {
			wp_delete_post( $page_get->ID );
		}
	}
	// Delete 'Sample Page'.
	if ( get_page_by_title( 'Sample Page' ) ) {
		$page_title = 'Sample Page';
		$page_get   = get_page_by_title( $page_title );
		if ( isset( $page_get->ID ) ) {
			wp_delete_post( $page_get->ID );
		}
	}
	// Create 'Sitemap'.
	if ( get_page_by_title( 'Sitemap' ) === null ) {
		$page_title  = 'Sitemap';
		$page_get    = get_page_by_title( $page_title );
		$page_create = array(
			'menu_order'  => '1000',
			'post_status' => 'publish',
			'post_title'  => $page_title,
			'post_type'   => 'page',
		);
		if ( ! isset( $page_get->ID ) ) {
			$page_id = wp_insert_post( $page_create );
			if ( ! empty( $page_template ) ) {
				update_post_meta( $page_id, '_wp_page_template', $page_template );
			}
		}
	}
	// Create 'Styleguide'.
	if ( get_page_by_title( 'Styleguide' ) === null ) {
		$page_title  = 'Styleguide';
		$page_get    = get_page_by_title( $page_title );
		$page_create = array(
			'menu_order'  => '1000',
			'post_status' => 'publish',
			'post_title'  => $page_title,
			'post_type'   => 'page',
		);
		if ( ! isset( $page_get->ID ) ) {
			$page_id = wp_insert_post( $page_create );
			if ( ! empty( $page_template ) ) {
				update_post_meta( $page_id, '_wp_page_template', $page_template );
			}
		}
	}

	// Permalinks.
	global $wp_rewrite;
	$wp_rewrite->set_permalink_structure( '/%year%/%monthnum%/%postname%' );
	$wp_rewrite->flush_rules();

	// Timezone.
	update_option( 'timezone_string', 'Australia/Melbourne' );

}
