<?php
/**
 * Taxonomy-related functions.
 * TO DO: fix validation error.
 *
 * @package WordPress
 * @version 1.0
 */

/**
 * Register custom taxonomy for the Media Library.
 */
function cm_media_library_tax() {
	register_taxonomy(
		'media_category',
		array( 'attachment' ),
		array(
			'has_archive'       => false,
			'hierarchical'      => true,
			'labels'            => array(
				'add_new_item'               => 'Add New Media Category',
				'add_or_remove_items'        => 'Add or remove media categories',
				'all_items'                  => 'All Media Categories',
				'choose_from_most_used'      => 'Choose from the most used media categories',
				'edit_item'                  => 'Edit Media Categories',
				'menu_name'                  => 'Media Categories',
				'name'                       => 'Media Categories',
				'new_item_name'              => 'New Media Category',
				'not_found'                  => 'No media categories found.',
				'parent_item'                => 'Parent Media Category',
				'parent_item_colon'          => 'Parent Media Category:',
				'popular_items'              => 'Popular Media Categories',
				'search_items'               => 'Search Media Categories',
				'separate_items_with_commas' => 'Separate media categories with commas',
				'singular_name'              => 'Media Category',
				'update_item'                => 'Update Media Category',
				'view_item'                  => 'View Media Category',
			),
			'public'            => true,
			'query_var'         => true,
			'rewrite'           => array(
				'hierarchical' => true,
				'slug'         => get_option( 'media_category_base' ),
				'with_front'   => true,
			),
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'show_tagcloud'     => false,
			'show_ui'           => true,
		)
	);
}
add_action( 'init', 'cm_media_library_tax' );

/**
 * Enqueue files to enable taxonomy drag and drop.
 */
function cm_taxonomy_position_scripts() {
	global $pagenow;
	if ( ! is_admin() ) {
		return $term_query;
	}
	if ( is_admin() && 'edit-tags.php' === $pagenow ) {
		wp_enqueue_script( 'jquery-ui-core' );
		wp_enqueue_script( 'jquery-ui-sortable' );
		wp_enqueue_script( 'taxonomy-position', get_template_directory_uri() . '/functions/assets/js/wp-admin.js', array( 'jquery-ui-core', 'jquery-ui-sortable' ), true, true );
		wp_localize_script(
			'taxonomy-position',
			'TaxonomyPosition',
			array(
				'ajax_url'      => esc_url( admin_url( 'admin-ajax.php' ) ),
				'preloader_url' => esc_url( admin_url( 'images/wpspin_light.gif' ) ),
			)
		);
	}
}
add_action( 'admin_enqueue_scripts', 'cm_taxonomy_position_scripts' );

/**
 * Enqueue files to enable taxonomy drag and drop.
 */
function cm_taxonomy_position_update() {
	$array_data = wp_unslash( $_POST['updated_array'] ); // phpcs:ignore
	foreach ( $array_data as $taxonomy_data ) {
		update_term_meta( $taxonomy_data[0], 'order', (int) ( $taxonomy_data[1] + 1 ) );
	}
	wp_die();
	exit;
}
add_action( 'wp_ajax_update_taxonomy_order', 'cm_taxonomy_position_update' );

/**
 * Set taxonomy ordering for 'product_cat'.
 *
 * @param  [type] $term_query  [description].
 */
function cm_taxonomy_position( $term_query ) {
	global $pagenow;
	if ( ! is_admin() ) {
		return $term_query;
	}
	// FAQ Categories.
	if ( is_admin() && 'edit-tags.php' === $pagenow && 'faq-category' === $term_query->query_vars['taxonomy'][0] && ( ! isset( $_GET['orderby'] ) || 'term_order' === $_GET['orderby'] ) ) { // phpcs:ignore
		$term_query->query_vars['orderby'] = 'order_clause';
		$term_query->query_vars['order']   = isset( $_GET['order'] ) ? $_GET['order'] : 'ASC'; // phpcs:ignore
		$args                              = array(
			'relation'     => 'OR',
			'order_clause' => array(
				'key'  => 'order',
				'type' => 'NUMERIC',
			),
			array(
				'key'     => 'order',
				'compare' => 'NOT EXISTS',
			),
		);
		$term_query->meta_query            = new WP_Meta_Query( $args );
	}
	// Person Roles.
	if ( is_admin() && 'edit-tags.php' === $pagenow && 'person-position' === $term_query->query_vars['taxonomy'][0] && ( ! isset( $_GET['orderby'] ) || 'term_order' === $_GET['orderby'] ) ) { // phpcs:ignore
		$term_query->query_vars['orderby'] = 'order_clause';
		$term_query->query_vars['order']   = isset( $_GET['order'] ) ? $_GET['order'] : 'ASC'; // phpcs:ignore
		$args                              = array(
			'relation'     => 'OR',
			'order_clause' => array(
				'key'  => 'order',
				'type' => 'NUMERIC',
			),
			array(
				'key'     => 'order',
				'compare' => 'NOT EXISTS',
			),
		);
		$term_query->meta_query            = new WP_Meta_Query( $args );
	}
	// Product Categories.
	if ( is_admin() && 'edit-tags.php' === $pagenow && 'product_cat' === $term_query->query_vars['taxonomy'][0] && ( ! isset( $_GET['orderby'] ) || 'term_order' === $_GET['orderby'] ) ) { // phpcs:ignore
		$term_query->query_vars['orderby'] = 'order_clause';
		$term_query->query_vars['order']   = isset( $_GET['order'] ) ? $_GET['order'] : 'ASC'; // phpcs:ignore
		$args                              = array(
			'relation'     => 'OR',
			'order_clause' => array(
				'key'  => 'order',
				'type' => 'NUMERIC',
			),
			array(
				'key'     => 'order',
				'compare' => 'NOT EXISTS',
			),
		);
		$term_query->meta_query            = new WP_Meta_Query( $args );
	}
	// Project Categories.
	if ( is_admin() && 'edit-tags.php' === $pagenow && 'project-category' === $term_query->query_vars['taxonomy'][0] && ( ! isset( $_GET['orderby'] ) || 'term_order' === $_GET['orderby'] ) ) { // phpcs:ignore
		$term_query->query_vars['orderby'] = 'order_clause';
		$term_query->query_vars['order']   = isset( $_GET['order'] ) ? $_GET['order'] : 'ASC'; // phpcs:ignore
		$args                              = array(
			'relation'     => 'OR',
			'order_clause' => array(
				'key'  => 'order',
				'type' => 'NUMERIC',
			),
			array(
				'key'     => 'order',
				'compare' => 'NOT EXISTS',
			),
		);
		$term_query->meta_query            = new WP_Meta_Query( $args );
	}
	// Reviews Categories.
	if ( is_admin() && 'edit-tags.php' === $pagenow && 'review-category' === $term_query->query_vars['taxonomy'][0] && ( ! isset( $_GET['orderby'] ) || 'term_order' === $_GET['orderby'] ) ) { // phpcs:ignore
		$term_query->query_vars['orderby'] = 'order_clause';
		$term_query->query_vars['order']   = isset( $_GET['order'] ) ? $_GET['order'] : 'ASC'; // phpcs:ignore
		$args                              = array(
			'relation'     => 'OR',
			'order_clause' => array(
				'key'  => 'order',
				'type' => 'NUMERIC',
			),
			array(
				'key'     => 'order',
				'compare' => 'NOT EXISTS',
			),
		);
		$term_query->meta_query            = new WP_Meta_Query( $args );
	}
	return $term_query;
}
add_filter( 'pre_get_terms', 'cm_taxonomy_position' );

/**
 * Show the WYSIWYG editor for all taxonomies.
 *
 * @param [type] $tag [description].
 */
function cm_show_description_editor( $tag ) {
	echo '<tr class="form-field">';
	echo '<th scope="row" valign="top">';
	echo '<label for="description">Description</label>';
	echo '</th>';
	echo '<td>';
	$settings = array(
		'media_buttons' => true,
		'quicktags'     => true,
		'textarea_name' => 'description',
		'textarea_rows' => '15',
		'wpautop'       => true,
	);
	wp_editor( html_entity_decode( wp_kses_post( $tag->description, ENT_QUOTES, 'UTF-8' ) ), 'cat_description', $settings );
	echo '<br />';
	echo '<p class="description">The description is not prominent by default; however, some themes may show it.</p>';
	echo '</td>';
	echo '</tr>';
}

/**
 * Set your taxonomies to use the WYSIWYG editor as set above.
 */
if ( is_admin() ) {
	// Remove the html filtering for descriptions.
	remove_filter( 'pre_term_description', 'wp_filter_kses' );
	remove_filter( 'term_description', 'wp_kses_data' );
	// Add support for your taxonomy with a filter when the taxonomy is registered.
	add_filter( 'edit_category_form_fields', 'cm_show_description_editor', 10, 1 );
	add_filter( 'faq-category_edit_form_fields', 'cm_show_description_editor', 10, 1 );
	add_filter( 'person-position_edit_form_fields', 'cm_show_description_editor', 10, 1 );
	add_filter( 'product_cat_edit_form_fields', 'cm_show_description_editor', 10, 1 );
	add_filter( 'project-category_edit_form_fields', 'cm_show_description_editor', 10, 1 );
	add_filter( 'review-category_edit_form_fields', 'cm_show_description_editor', 10, 1 );
}
