<?php
/**
 * Welcome screen customisations.
 *
 * @package WordPress
 * @version 1.0
 */

/**
 * Show the Welcome panel.
 */
function cm_welcome_panel() {
	echo '<div id="welcome-panel" class="welcome-panel" style="margin: 16px 8px;">';
	echo '<div class="welcome-panel-content">';
	echo '<h2>Welcome to your WordPress website, developed by Circle Media</h2>';
	echo '<p class="about-description">What would you like to do?</p>';
	echo '<div class="welcome-panel-column-container">';
	echo '<div class="welcome-panel-column welcome-panel-last">';
	echo '<h3>Add new content</h3>';
	$custom_post_types = get_post_types(
		array(),
		'objects'
	);
	ksort( $custom_post_types, SORT_ASC );
	// Don't include these CPTs.
	$exclude = array(
		'acf-field',
		'acf-field-group',
		'attachment',
		'customize_changeset',
		'custom_css',
		'nav_menu_item',
		'oembed_cache',
		'product_variation',
		'redirect_rule',
		'revision',
		'sb_ads',
		'sb_posts',
		'sb_themes',
		'shop_coupon',
		'shop_order',
		'shop_order_refund',
		'user_request',
		'wp_block',
		'wpcf7_contact_form',
	);
	echo '<ul>';
	// Get all the public CPTs except for those in the excluded list above.
	foreach ( $custom_post_types as $custom_post_type ) {
		$cpt      = get_post_type_object( $custom_post_type->name );
		$cpt_name = $cpt->labels->singular_name;
		if ( true === in_array( $custom_post_type->name, $exclude, true ) ) {
			continue;
		}
		echo '<li>';
		echo '<a href="' . esc_url( site_url() ) . '/wp-admin/post-new.php?post_type=' . esc_html( $custom_post_type->name ) . '" class="welcome-icon welcome-edit-page">Add new ' . esc_html( $cpt_name ) . '</a>';
		echo '</li>';
	}
	echo '</ul>';
	echo '</div>';
	echo '<div class="welcome-panel-column">';
	echo '<h3>Edit content</h3>';
	$custom_post_types = get_post_types(
		array(),
		'objects'
	);
	ksort( $custom_post_types, SORT_ASC );
	echo '<ul>';
	// Get all the public CPTs except for those in the excluded list above.
	foreach ( $custom_post_types as $custom_post_type ) {
		$cpt      = get_post_type_object( $custom_post_type->name );
		$cpt_name = $cpt->labels->singular_name;
		if ( true === in_array( $custom_post_type->name, $exclude, true ) ) {
			continue;
		}
		echo '<li>';
		echo '<a href="' . esc_url( site_url() ) . '/wp-admin/edit.php?post_type=' . esc_html( $custom_post_type->name ) . '" class="welcome-icon welcome-edit-page">Edit ' . esc_html( $cpt_name ) . '</a>';
		echo '</li>';
	}
	echo '</div>';
	echo '<div class="welcome-panel-column welcome-panel-last">';
	echo '<h3>More actions</h3>';
	echo '<ul>';
	echo '<li><a href="' . esc_url( home_url() ) . '" class="welcome-icon welcome-view-site">View your site</a></li>';
	echo '</ul>';
	echo '</div>';
	echo '</div>';
	echo '</div>';
	echo '</div>';
	echo '<script>';
	echo 'jQuery(document).ready(function($) {';
	echo '$( \'#dashboard-widgets\' ).before( $( \'#welcome-panel\' ).show());';
	echo '});';
	echo '</script>';
}
// Remove the WordPress welcome panel.
remove_action( 'welcome_panel', 'wp_welcome_panel' );
// Replace it with ours.
// add_action( 'welcome_panel', 'cm_welcome_panel' );

/**
 * Show welcome panel for non-admin users.
 */
/* function cm_welcome_panel_display() {
	$user_id = get_current_user_id();
	if ( 1 !== get_user_meta( $user_id, 'cm_welcome_panel_display', true ) ) {
		update_user_meta( $user_id, 'cm_welcome_panel_display', 1 );
	}
}
add_action( 'load-index.php', 'cm_welcome_panel_display' ); */

// Custom Dashboard
function my_custom_dashboard() {
	if ( get_current_screen()->base !== 'dashboard' ) {
		return;
	}
	cm_welcome_panel();
}

add_action( 'admin_footer', 'my_custom_dashboard' );
