<?php
/**
 * Blog archive/index template.
 *
 * @package WordPress
 * @version 1.0
 */

get_header();
$archive_id   = get_option( 'page_for_posts' );
$date_format  = 'F j Y';
$page_form    = get_post_meta( $archive_id, '_page_form', true );
$page_form_id = get_post_meta( $archive_id, '_page_form_id', true );
$page_sidebar = get_post_meta( $archive_id, '_page_sidebar', true );
$pagination   = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
$seotitle     = get_post_meta( $archive_id, '_seo_heading', true );
if ( $page_sidebar ) {
	$sidebar_status = ' has-sidebar';
} else {
	$sidebar_status = '';
}
?>
<main class="archive archive--blog content page page--internal page--<?php echo esc_html( sanitize_title_with_dashes( get_the_title( $archive_id ) ) ); ?>">
	<?php get_template_part( 'partials/hero/static' ); ?>
	<article class="container<?php echo esc_attr( $sidebar_status ); ?>">
		<section class="main">
			<?php
			get_template_part( 'partials/menu/breadcrumbs' );
			get_template_part( 'partials/content/title' );
			if ( 1 === $pagination && is_home() ) {
				$archive_introduction = get_post( $archive_id );
				echo wp_kses_post( apply_filters( 'the_content', $archive_introduction->post_content ) );
				wp_reset_postdata();
			}
			if ( have_posts() ) {
				echo '<div class="posts">';
				while ( have_posts() ) {
					the_post();
					echo '<div id="post-' . esc_attr( get_the_ID() ) . '" class="' . esc_attr( join( ' ', get_post_class( 'split' ) ) ) . '">';
					if ( has_post_thumbnail() ) {
						$img        = get_post_meta( get_the_ID(), '_thumbnail_id', true );
						$img_cap    = get_post_meta( $img, '_wp_attachment_image_alt', true );
						$img_size   = 'square-medium';
						$img_h      = wp_get_attachment_image_src( $img, $img_size )[2];
						$img_w      = wp_get_attachment_image_src( $img, $img_size )[1];
						$img_url    = wp_get_attachment_image_url( $img, $img_size );
						$img_srcset = wp_get_attachment_image_srcset( $img, $img_size );
						echo '<div class="post-image">';
						echo '<a href="' . esc_url( get_the_permalink() ) . '">';
						echo '<img loading="lazy" src="' . esc_url( $img_url ) . '" height="' . esc_attr( $img_h ) . '" width="' . esc_attr( $img_w ) . '" alt="' . esc_html( do_shortcode( $img_cap ? $img_cap : '' ) ) . '" title="' . esc_html( do_shortcode( $img_cap ? $img_cap : '' ) ) . '" srcset="' . esc_attr( $img_srcset ) . '" />';
						echo '</a>';
						echo '</div>';
					};
					echo '<div class="post-excerpt">';
					echo '<time datetime="' . esc_attr( get_the_time( 'Y-m-d' ) ) . '" class="meta">' . esc_attr( get_the_time( $date_format ) ) . '</time>';
					echo '<h3><a href="' . esc_url( get_the_permalink() ) . '" class="post-title">' . esc_html( get_the_title() ) . '</a></h3>';
					if ( function_exists( 'content_excerpt' ) ) {
						echo wp_kses_post( content_excerpt( get_the_ID(), 55 ) );
					} else {
						the_excerpt();
					};
					echo ' <a href="' . esc_url( get_permalink() ) . '" class="post-continue continue">continue&nbsp;reading&nbsp;' . wp_kses_post( get_fa( 'fa-long-arrow-right' ) ) . '</a>';
					echo '</div>';
					echo '</div>';
				}
			}
			echo '</div>';
			get_template_part( 'partials/content/pagination' );
			?>
		</section>
		<aside class="sidebar sidebar--rhs">
			<?php get_sidebar(); ?>
		</aside>
	</article>
</main>
<?php
get_footer();

