<?php
/**
 * Pre-filled privacy policy.
 *
 * @package WordPress
 */

$location_id = get_option( 'theme_location_id' );
$site_title  = get_bloginfo( 'name' );
if ( $location_id ) {
	$city     = get_post_meta( $location_id, '_location_address_city', true );
	$email    = get_post_meta( $location_id, '_location_email_address', true );
	$line1    = get_post_meta( $location_id, '_location_address_line1', true );
	$line2    = get_post_meta( $location_id, '_location_address_line2', true );
	$line3    = get_post_meta( $location_id, '_location_address_line3', true );
	$postcode = get_post_meta( $location_id, '_location_address_postcode', true );
	$state    = get_post_meta( $location_id, '_location_address_state', true );
	$tel      = get_post_meta( $location_id, '_location_telephone_number', true );
}
echo '<p>This following document sets forth the Privacy Policy for the ' . esc_html( $site_title ) . ' website, ' . esc_url( home_url() ) . '.</p>';
echo '<p>' . esc_html( $site_title ) . ' is committed to providing you with the best possible customer service experience. ' . esc_html( $site_title ) . ' is bound by the Privacy Act 1988 (Cth), which sets out a number of principles concerning the privacy of individuals.</p>';
echo '<h3>Collection of your personal information</h3>';
echo '<p>There are many aspects of the site which can be viewed without providing personal information, however, for access to future ' . esc_html( $site_title ) . ' customer support features you are required to submit personally identifiable information. This may include but not limited to a unique username and password, or provide sensitive information in the recovery of your lost password.</p>';
echo '<h3>Sharing of your personal information</h3>';
echo '<p>We may occasionally hire other companies to provide services on our behalf, including but not limited to handling customer support enquiries, processing transactions or customer freight shipping. Those companies will be permitted to obtain only the personal information they need to deliver the service. ' . esc_html( $site_title ) . ' takes reasonable steps to ensure that these organisations are bound by confidentiality and privacy obligations in relation to the protection of your personal information.</p>';
echo '<h3>Use of your personal information</h3>';
echo '<p>For each visitor to reach the site, we expressively collect the following non-personally identifiable information, including but not limited to browser type, version and language, operating system, pages viewed while browsing the Site, page access times and referring website address. This collected information is used solely internally for the purpose of gauging visitor traffic, trends and delivering personalized content to you while you are at this Site.</p>';
echo '<p>From time to time, we may use customer information for new, unanticipated uses not previously disclosed in our privacy notice. If our information practices change at some time in the future we will use for these new purposes only, data collected from the time of the policy change forward will adhere to our updated practices.</p>';
echo '<h3>Changes to this Privacy Policy</h3>';
echo '<p>' . esc_html( $site_title ) . '	reserves the right to make amendments to this Privacy Policy at any time. If you have objections to the Privacy Policy, you should not access or use the Site.';
echo '<h3>Accessing Your Personal Information</h3>';
echo '<p>You have a right to access your personal information, subject to exceptions allowed by law. If you would like to do so, please let us know. You may be required to put your request in writing for security reasons. ' . esc_html( $site_title ) . ' reserves the right to charge a fee for searching for, and providing access to, your information on a per request basis.</p>';
echo '<h3>Contacting us</h3>';
echo '<p>' . esc_html( $site_title ) . ' welcomes your comments regarding this Privacy Policy. If you have any questions about this Privacy Policy and would like further information, please contact us during business hours Monday to Friday.</p>';
if ( $location_id ) {
	if ( $tel ) {
		echo '<p><strong>Call</strong> ' . esc_html( $tel ) . '</p>';
	}
	if ( $email ) {
		echo '<p><strong>Email</strong> ' . esc_html( $email ) . '</p>';
	}
	if ( $line1 || $line2 || $line3 || $city || $state || $postcode ) {
		echo '<p><strong>Post</strong> Attn: Privacy Policy';
		if ( $line1 ) {
			echo '<br />' . esc_html( $line1 );
		}
		if ( $line1 && $line2 ) {
			echo '<br />' . esc_html( $line2 );
		};
		if ( $line1 && $line2 && $line3 ) {
			echo '<br />' . esc_html( $line3 );
		};
		if ( $city ) {
			echo '<br />' . esc_html( $city );
			if ( ( $city && $state ) || ( $city && $postcode && ! $state ) ) {
				echo ', ';
			}
		}
		if ( $state ) {
			echo esc_html( $state );
			if ( ( $state && $postcode ) || ( $city && $postcode && ! $state ) ) {
				echo ' ';
			}
			// Postcode.
			echo $postcode ? esc_html( $postcode ) : '';
		}
		echo '</p>';
	}
}
