<?php
/**
 * Partial for calling titles throughout the theme.
 *
 * @package WordPress
 * @version 1.0
 */

echo '<h1 class="page-title">';

// Pages.
if ( is_page() ) {
	if ( function_exists( 'the_h1' ) ) {
		echo esc_html( do_shortcode( the_h1( get_the_ID() ) ) );
	} else {
		echo esc_html( do_shortcode( get_the_title( get_the_ID() ) ) );
	};
}

// Posts / Products.
if ( is_single() ) {
	the_title();
}

// Blog archives.
if ( is_blog() && ! is_single() ) {
	$archive_id = get_option( 'page_for_posts' );
	$seotitle   = get_post_meta( $archive_id, '_seo_heading', true );
	if ( is_category() ) {
		echo 'Category: ';
		echo single_cat_title();
	} elseif ( is_day() ) {
		echo 'Daily Archive: ' . esc_attr( get_the_time( 'F j Y' ) );
	} elseif ( is_month() ) {
		echo 'Monthly Archive: ' . esc_attr( get_the_time( 'F Y' ) );
	} elseif ( is_year() ) {
		echo 'Yearly Archive: ' . esc_attr( get_the_time( 'Y' ) );
	} else {
		if ( $seotitle ) {
			echo esc_html( do_shortcode( $seotitle ) );
		} else {
			echo esc_html( get_bloginfo( 'name' ) . ' ' . do_shortcode( get_the_title( $archive_id ) ) );
		}
	}
}

// Product archives.
if ( is_post_type_archive( 'product' ) ) {
	if ( class_exists( 'WooCommerce' ) ) {
		$archive_id = get_option( 'woocommerce_shop_page_id' );
	} else {
		$archive_id = get_option( 'options_cpt_default_product_archive' );
	}
	$seotitle = get_post_meta( $archive_id, '_seo_heading', true );
	if ( $seotitle ) {
		echo esc_html( do_shortcode( $seotitle ) );
	} else {
		echo esc_html( do_shortcode( get_the_title( $archive_id ) ) );
	}
}

// Taxonomies.
if ( is_tax() ) {
	$taxonomy_id = get_queried_object()->term_id;
	$seotitle    = get_term_meta( $taxonomy_id, '_seo_heading', true );
	if ( $seotitle ) {
		echo esc_html( do_shortcode( $seotitle ) );
	} else {
		single_cat_title();
	}
}

// Search results.
if ( is_search() ) {
	if ( have_posts() ) {
		global $wp_query;
		$results = $wp_query->found_posts;
		echo 'Found ' . esc_attr( $results );
	} else {
		$results = 0;
		echo 'No';
	}
	if ( '1' === $results ) {
		echo ' search result ';
	} else {
		echo ' search results ';
	}
	echo 'for &lsquo;' . get_search_query() . '&rsquo;';
}

// 404 page.
if ( is_404() ) {
	echo 'Sorry, nothing found';
}

echo '</h1>';
