<?php
/**
 * Address partial. Utilises 'did_action( 'get_footer' )' to show more
 * information depending on where partial was called from. Modify to
 * suit your needs.
 *
 * @package WordPress
 * @version 1.0
 */

$location_id = get_option( 'theme_location_id' );
if ( $location_id ) {
	$city     = get_post_meta( $location_id, '_location_address_city', true );
	$email    = get_post_meta( $location_id, '_location_contact_primary_email', true );
	$fax      = get_post_meta( $location_id, '_location_contact_fax', true );
	$line1    = get_post_meta( $location_id, '_location_address_line1', true );
	$line2    = get_post_meta( $location_id, '_location_address_line2', true );
	$line3    = get_post_meta( $location_id, '_location_address_line3', true );
	$phone    = get_post_meta( $location_id, '_location_contact_primary_telephone', true );
	$postcode = get_post_meta( $location_id, '_location_address_postcode', true );
	$schema   = get_post_meta( $location_id, '_location_schema_classification', true );
	$state    = get_post_meta( $location_id, '_location_address_state', true );
	if ( $email ) {
		$email_link = antispambot( $email, 1 );
	}
	// Begin output.
	echo '<div itemscope itemtype="http://schema.org/' . esc_attr( $schema ) . '" class="location site-footer--location">';
	echo '<address itemprop="address" itemscope itemtype="http://schema.org/PostalAddress">';
	// Primary Contact.
	if ( $phone ) {
		echo '<div class="location--telephone">';
		if ( $phone ) {
			$phone = str_replace( array( '(', ')' ), '', $phone );
			echo '<a href="tel:' . esc_html( str_replace( ' ', '', $phone ) ) . '" itemprop="telephone" onclick="ga(\'send\',\'event\',\'phone call\',\'click\');" x-ms-format-detection="none">' . esc_html( $phone ) . '</a>';
		}
		echo '</div>';
	}
	// Email.
	echo $email ? '<div class="location--email" itemprop="email"><a href="mailto:' . esc_html( $email_link ) . '">' . esc_html( $email ) . '</a></div>' : '';
	// Street Address.
	if ( $line1 || $line2 || $line3 || $city || $postcode || $state ) {
		echo '<div class="location--address">';
	}
	if ( $line1 || $line2 || $line3 ) {
		echo '<div class="location--street" itemprop="streetAddress">' . esc_html( $line1 );
		if ( $line1 && $line2 ) {
			echo '<span>' . esc_html( $line2 ) . '</span>';
		};
		if ( $line1 && $line2 && $line3 ) {
			echo '<span>' . esc_html( $line3 ) . '</span>';
		};
		echo '</div>';
	};
	if ( $city || $postcode || $state ) {
		echo '<div class="location--locality">';
		// City.
		echo $city ? '<span itemprop="addressLocality">' . esc_html( $city ) . '</span>' : '';
		if ( ( $city && $state ) || ( $city && $postcode && ! $state ) ) {
			echo ', ';
		}
		// State.
		echo $state ? '<span itemprop="addressRegion">' . esc_html( $state ) . '</span>' : '';
		if ( ( $state && $postcode ) || ( $city && $postcode && ! $state ) ) {
			echo ' ';
		}
		// Postcode.
		echo $postcode ? '<span itemprop="postalCode">' . esc_html( $postcode ) . '</span>' : '';
		echo '</div>';
	}
	if ( $line1 || $line2 || $line3 || $city || $postcode || $state ) {
		echo '</div>';
	}
	echo '</address>';
	echo '</div>';
}
wp_reset_postdata();
