<?php
/**
 * Search results template.
 * Inspired by: http://atastypixel.com/blog/keeping-blog-visitors-by-showing-meaningful-search-results-in-wordpress/
 *
 * @package WordPress
 * @version 1.0
 */

// If your theme doesn't have a search page/function, uncomment this bad boy.
/* wp_safe_redirect( esc_url( home_url() ) ); */
$date_format = 'F j Y';
$max_length  = 400; // Maximim length in characters.
$min_padding = 30; // Minimin length in characters of the context to place around found search terms.
get_header(); ?>
<main class="archive search archive--search">
	<div class="container">
		<div class="content">
			<?php
			get_template_part( 'partials/content/title' );
			if ( have_posts() ) {
				echo '<div class="archive--search--search-results search-results">';
				while ( have_posts() ) {
					the_post();
					$result_post_type = get_post_type( get_the_ID() );
					if ( 'product' === $result_post_type ) {
						$continue = 'View product';
					} elseif ( 'project' === $result_post_type ) {
						$continue = 'View project';
					} else {
						$continue = 'Read more';
					}
					echo '<div id="search-result-' . esc_attr( get_the_ID() ) . '" class="' . esc_attr( join( ' ', get_post_class( 'search-result' ) ) ) . '">';
					echo '<div class="search-result--excerpt">';
					echo '<h3><a href="' . esc_url( get_the_permalink() ) . '" class="result--title">' . get_the_title() . '</a></h3>';
					if ( 'post' === $result_post_type ) {
						echo '<time datetime="' . esc_attr( get_the_time( 'Y-m-d' ) ) . '">' . esc_attr( get_the_time( $date_format ) ) . '</time>';
					}
					$result_content = ( ! post_password_required( $post ) ? wp_strip_all_tags( preg_replace( array( "/\r?\n/", '@<\s*(p|br\s*/?)\s*>@' ), array( ' ', "\n" ), apply_filters( 'the_content', $post->post_content ) ) ) : '' );
					// Search content for the search term.
					$terms = $wp_query->query_vars['search_terms'];
					if ( preg_match_all( '/' . str_replace( '/', '\/', join( '|', $terms ) ) . '/i', $result_content, $matches, PREG_OFFSET_CAPTURE ) ) {
						$padding = max( $min_padding, $max_length / ( 2 * count( $matches[0] ) ) );
						// Construct extract containing context for each term.
						$output      = '';
						$last_offset = 0;
						foreach ( $matches[0] as $match ) {
							list($string, $offset) = $match;
							$search_term_start     = $offset - $padding;
							$search_term_end       = $offset + strlen( $string ) + $padding;
							// Preserve whole words.
							while ( $search_term_start > 1 && preg_match( '/[A-Za-z0-9\'"-]/', $result_content{intval( $search_term_start - 1 )} ) ) {
								$search_term_start--;
							}
							$result_strlen = strlen( $result_content );
							while ( $search_term_end < $result_strlen - 1 && preg_match( '/[A-Za-z0-9\'"-]/', $result_content{intval( $search_term_end )} ) ) {
								$search_term_end++;
							}
							$search_term_start   = max( $search_term_start, $last_offset );
							$search_term_context = substr( $result_content, $search_term_start, $search_term_end - $search_term_start );
							if ( $search_term_start > $last_offset ) {
								$search_term_context = '...' . $search_term_context;
							}
							$output     .= $search_term_context;
							$last_offset = $search_term_end;
						}

						if ( $last_offset !== $result_strlen - 1 ) {
							$output .= '...';
						}
					} else {
						$output = $result_content;
					}
					if ( strlen( $output ) > $max_length ) {
						$search_term_end = $max_length - 3;
						while ( $search_term_end > 1 && preg_match( '/[A-Za-z0-9\'"-]/', $output{$search_term_end - 1} ) ) {
							$search_term_end--;
						}
						$output = substr( $output, 0, $search_term_end ) . '...';
					}
					// Highlight words and parts of words that match the search term.
					$search_term_context = preg_replace( '/' . str_replace( '/', '\/', join( '|', $terms ) ) . '/i', '<span class="highlight">$0</span>', $output );
					echo wp_kses_post( $search_term_context );
					echo ' <a href="' . esc_url( get_permalink() ) . '" class="search-result--continue continue">' . esc_html( $continue ) . ' ' . wp_kses_post( get_fa( 'fa-angle-right' ) ) . '</a>';
					echo '</div>';
					echo '</div>';
				}
			} else {
				echo '<p>The content you are looking for cannot be found. Please search again, <a href="' . esc_html( home_url() ) . '">return to the home page</a>, or make a selection from the menu.</p>';
			}
			get_template_part( 'partials/pagination' );
			?>
		</div>
	</div>
</main>
<?php
get_footer();
